/*
|--------------------------------------------------------------------------
| apola.newsletter.js
|--------------------------------------------------------------------------
| Defines subscribe module.
*/
;(function($){
	'use strict';

	if(!('Apola' in $)) {
		throw new Error('apola.core.js file must be included.');
	};

	var _config = {
		url: 'php/subscribe.php',
		onSuccess: function(data){},
		onError: function(data){}
	};

	$.Apola.modules.newsletter = function( collection, config ) {
		if(!collection || !collection.length) return false;
		config = config && $.isPlainObject(config) ? $.extend(true, {}, _config, config) : _config;

		return collection.each(function(i, el){
			var $this = $(el);
			if($this.data('Newsletter')) return;
			$this.data('Newsletter', new Newsletter($this, config));
		});
	};

	function Newsletter(form, config) {
		var self = this;

		this.form = form;
		this.config = config;

		this.initValidator();
		form.data('config', config);
	};

	Newsletter.prototype.initValidator = function(){

		var self = this;

		if(!(this.form.get(0) instanceof HTMLFormElement) || !window.Validator) return;

		this.form.data('validator', new Validator({
			form: self.form.get(0),
			cssPrefix: 'apo-',
			incorrectClass: 'invalid',
			correctClass: 'valid',
			rules: [
				{
					element: self.form.get(0).elements['email'],
					name: 'Email',
					rules: {
						empty: null,
						pattern: /^(([^<>()\[\]\.,;:\s@\"]+(\.[^<>()\[\]\.,;:\s@\"]+)*)|(\".+\"))@(([^<>()[\]\.,;:\s@\"]+\.)+[^<>()[\]\.,;:\s@\"]{2,})$/i
					}
				}
			],
			onIncorrect: function(errorsList){

				$.Apola.modules.alertMessage({
					target: self.form,
					type: 'error',
					icon: 'warning',
					message: errorsList
				});

			},
			onCorrect: self.send
		}));

	};

	Newsletter.prototype.send = function() {
		var $form = $(this),
			config = $form.data('config');

		$.ajax({
			url: config.url,
			type: 'POST',
			dataType: 'json',
			data: $form.serialize(),
			success: function(data){
				if(data.status && data.status == 'fail') {
					$.Apola.modules.alertMessage({
						target: $form,
						type: 'error',
						message: data.errors,
						icon: 'warning'
					});
					config.onError.call($form, data);
				}
				else if(data.status && data.status == 'success') {
					$.Apola.modules.alertMessage({
						target: $form,
						type: 'success',
						message: data.statusText,
						icon: 'check'
					});
					config.onSuccess.call($form, data);
				}
			},
			error: function(jqXHR, textStatus, errorThrown){
				$.Apola.modules.alertMessage({
					target: $form,
					type: 'error',
					message: errorThrown,
					icon: 'warning'
				});
				config.onError.call($form, arguments);
			}
		});
	}


})(jQuery);