<?php
/**
 * Apola functions and definitions
 *
 * Set up the theme and provides some helper functions, which are used in the
 * theme as custom template tags. Others are attached to action and filter
 * hooks in WordPress to change core functionality.
 *
 * When using a child theme you can override certain functions (those wrapped
 * in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before
 * the parent theme's file, so the child theme functions would be used.
 *
 * @link https://codex.wordpress.org/Theme_Development
 * @link https://codex.wordpress.org/Child_Themes
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are
 * instead attached to a filter or action hook.
 *
 * For more information on hooks, actions, and filters,
 * {@link https://codex.wordpress.org/Plugin_API}
 *
 * @package WordPress
 * @since Apola 1.0
 */
 // Prevent the direct loading of the file
 if ( ! defined( 'ABSPATH' ) ) {
 	die( esc_html__('You cannot access this file directly', 'apola') );
 }

 /*  Main Constants
 /* ---------------------------------------------------------------------- */
 define('APOLA_TEMPLATE_DIRECTORY', get_template_directory());
 define('APOLA_TEMPLATE_DIRECTORY_URI', get_template_directory_uri());
 define('APOLA_STYLESHEET_DIRECTORY', get_stylesheet_directory());

/* Including of the required theme files
/* ---------------------------------------------------------------------- */
require_once(APOLA_TEMPLATE_DIRECTORY . '/includes/functions-core.php');
require_once(APOLA_TEMPLATE_DIRECTORY . '/includes/hooks.php');
require_once(APOLA_TEMPLATE_DIRECTORY . '/includes/widget-areas.php');
require_once(APOLA_TEMPLATE_DIRECTORY . '/includes/config-contact-form-7/ApolaContactForm7Config.php');

require_once(APOLA_TEMPLATE_DIRECTORY . '/admin/domain/ConfigurableInterface.php');
require_once(APOLA_TEMPLATE_DIRECTORY . '/admin/domain/ApolaConfigurator.php');
require_once(APOLA_TEMPLATE_DIRECTORY . '/admin/domain/ApolaAdmin.php');
require_once(APOLA_TEMPLATE_DIRECTORY . '/admin/apola-plugins-bundle.php');

require_once(APOLA_TEMPLATE_DIRECTORY . '/includes/domain/Apola.php');
require_once(APOLA_TEMPLATE_DIRECTORY . '/includes/domain/ApolaHelper.php');

/*  Theme support & Theme setup
/* ---------------------------------------------------------------------- */
if ( ! function_exists( 'apola_setup' ) ) {
	function apola_setup() {

        global $Apola, $content_width;

		$content_width = apply_filters( 'apola_content_width', 1140 );

		// Load theme textdomain
		load_theme_textdomain( 'apola', APOLA_TEMPLATE_DIRECTORY  . '/lang' );
		load_child_theme_textdomain( 'apola', APOLA_STYLESHEET_DIRECTORY . '/lang' );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );


		// Post Thumbnails Support
		add_theme_support('post-thumbnails');

		// Add default posts and comments RSS feed links to head
		add_theme_support('automatic-feed-links');

		add_theme_support('title-tag');

        // Add custom image sizes
        add_image_size('apola-team-member-thumb', 555, 514, true);
        add_image_size('apola-portfolio-thumb-horizontal', 940, 940, true);
        add_image_size('apola-portfolio-thumb-vertical', 870, 1085, true);
        add_image_size('apola-blog-thumb-horizontal', 1140, 855, true);
        add_image_size('apola-blog-thumb-vertical', 1140, 1200, true);
        add_image_size('apola-full-screen-thumb', 2560, 1600, true);

		// This theme uses wp_nav_menu() in one location.
		register_nav_menu( 'primary', 'Primary Menu' );

		add_theme_support( 'custom-header', apply_filters( 'apola_custom_header_args', array(
			'width' => 1140,
		) ) );

		// Setup the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'apola_custom_background_args', array(
			'default-color'      => '#fff',
			'default-attachment' => 'fixed',
		) ) );

		// This theme uses its own gallery styles.
		add_filter( 'use_default_gallery_style', '__return_false' );

        // Initialization theme core objects
		$Apola = new Apola( new ApolaAdmin( new ApolaConfigurator() ), new ApolaHelper() );
	}
}
add_action( 'after_setup_theme', 'apola_setup', 100 );

/*  Including editor's stylesheet
/* ---------------------------------------------------------------------- */
if (!function_exists( 'apola_theme_add_editor_styles')) {
    function apola_theme_add_editor_styles() {
        add_editor_style('custom-editor-style.css');
    }
}
add_action('init', 'apola_theme_add_editor_styles');

?>
