<?php
/**
* The main template file that is responsible to display the site header.
*
* @package WordPress
* @subpackage Apola
* @since Apola 1.0
*/

// Prevent the direct loading of the file
if ( ! defined( 'ABSPATH' ) ) {
	die( esc_html__('You cannot access this file directly', 'apola') );
}

global $Apola;

$ApolaHelper = $Apola->helper();

$apola_header_type = $Apola->getThemeOption('apola-header-type', 'apola-header-side', array(
	'overriden_by' => 'apola-page-header-type-individual',
	'depend_on' => array( 'key' => 'apola-page-header-state-individual', 'value' => '0' )
));
$apola_current_page_type = $Apola->getThemeOption('apola-page-type', 'apola-default', array(
	'overriden_by' => 'apola-page-type-individual',
	'depend_on' => array('key' => 'apola-page-settings-inherit-individual', 'value' => 0)
));
$apola_current_page_style = $Apola->getThemeOption('apola-page-type-portfolio-gallery-page-style', 'apola-grid');
$apola_container_classes = array();
$apola_favicon = $Apola->getThemeOption('apola-favicon', null);
$apola_apple_touch_icon = $Apola->getThemeOption('apola-apple-touch-icon', null);
$apola_apple_touch_icon_57x57 = $Apola->getThemeOption('apola-apple-touch-icon-57x57', null);
$apola_apple_touch_icon_72x72 = $Apola->getThemeOption('apola-apple-touch-icon-72x72', null);
$apola_apple_touch_icon_76x76 = $Apola->getThemeOption('apola-apple-touch-icon-76x76', null);
$apola_apple_touch_icon_114x114 = $Apola->getThemeOption('apola-apple-touch-icon-114x114', null);
$apola_apple_touch_icon_120x120 = $Apola->getThemeOption('apola-apple-touch-icon-120x120', null);
$apola_apple_touch_icon_144x144 = $Apola->getThemeOption('apola-apple-touch-icon-144x144', null);
$apola_apple_touch_icon_152x152 = $Apola->getThemeOption('apola-apple-touch-icon-152x152', null);
$apola_apple_touch_icon_180x180 = $Apola->getThemeOption('apola-apple-touch-icon-180x180', null);


if(!is_singular('apola-galleries') && !in_array($apola_current_page_style, array('apola-slideshow', 'apola-full-page', 'apola-striped-carousel')) && !is_post_type_archive('apola-galleries') && !is_post_type_archive('apola-portfolio') && !is_tax('apola-portfolio-categories') && !is_tax('apola-gallery-categories') && !in_array($apola_current_page_type, array('apola-fullpage-fixed-image'))) {
	array_push($apola_container_classes, 'container');
}
else {
	array_push($apola_container_classes, 'apola-full-width-container');
}
?>
<!DOCTYPE html>
<!--[if (gte IE 9)|!(IE)]><!--> <html class="not-ie no-js" <?php language_attributes(); ?>>  <!--<![endif]-->
<head>

	<!-- Basic Page Needs
    ==================================================== -->
	<meta charset="<?php bloginfo( 'charset' ); ?>" />
	<!--[if IE]><meta http-equiv='X-UA-Compatible' content='IE=edge,chrome=1'><![endif]-->

	<!-- Mobile Specific Metas
	==================================================== -->
	<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">

	<link rel="profile" href="http://gmpg.org/xfn/11" />

	<?php if ( is_singular() && pings_open() ) : ?>
		<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
	<?php endif; ?>


	<?php if(is_array($apola_favicon) && isset($apola_favicon['url']) && !empty($apola_favicon['url'])) : ?>
	<!-- Favicon
	==================================================== -->
	<link rel="shortcut icon" href="<?php echo esc_url($apola_favicon['url']); ?>">
	<?php endif; ?>

	<!-- Apple touch icons
	============================================ -->
	<?php if(is_array($apola_apple_touch_icon) && isset($apola_apple_touch_icon['url']) && !empty($apola_apple_touch_icon['url'])) : ?>
	<link rel="apple-touch-icon" href="<?php echo esc_url($apola_apple_touch_icon['url']); ?>">
	<?php endif; ?>
	<?php if(is_array($apola_apple_touch_icon_57x57) && isset($apola_apple_touch_icon_57x57['url']) && !empty($apola_apple_touch_icon_57x57['url'])) : ?>
	<link rel="apple-touch-icon" sizes="57x57" href="<?php echo esc_url($apola_apple_touch_icon_57x57['url']); ?>">
	<?php endif; ?>
	<?php if(is_array($apola_apple_touch_icon_72x72) && isset($apola_apple_touch_icon_72x72['url']) && !empty($apola_apple_touch_icon_72x72['url'])) : ?>
	<link rel="apple-touch-icon" sizes="72x72" href="<?php echo esc_url($apola_apple_touch_icon_72x72['url']); ?>">
	<?php endif; ?>
	<?php if(is_array($apola_apple_touch_icon_76x76) && isset($apola_apple_touch_icon_76x76['url']) && !empty($apola_apple_touch_icon_76x76['url'])) : ?>
	<link rel="apple-touch-icon" sizes="76x76" href="<?php echo esc_url($apola_apple_touch_icon_76x76['url']); ?>">
	<?php endif; ?>
	<?php if(is_array($apola_apple_touch_icon_114x114) && isset($apola_apple_touch_icon_114x114['url']) && !empty($apola_apple_touch_icon_114x114['url'])) : ?>
	<link rel="apple-touch-icon" sizes="114x114" href="<?php echo esc_url($apola_apple_touch_icon_114x114['url']); ?>">
	<?php endif; ?>
	<?php if(is_array($apola_apple_touch_icon_120x120) && isset($apola_apple_touch_icon_120x120['url']) && !empty($apola_apple_touch_icon_120x120['url'])) : ?>
	<link rel="apple-touch-icon" sizes="120x120" href="<?php echo esc_url($apola_apple_touch_icon_120x120['url']); ?>">
	<?php endif; ?>
	<?php if(is_array($apola_apple_touch_icon_144x144) && isset($apola_apple_touch_icon_144x144['url']) && !empty($apola_apple_touch_icon_144x144['url'])) : ?>
	<link rel="apple-touch-icon" sizes="144x144" href="<?php echo esc_url($apola_apple_touch_icon_144x144['url']); ?>">
	<?php endif; ?>
	<?php if(is_array($apola_apple_touch_icon_152x152) && isset($apola_apple_touch_icon_152x152['url']) && !empty($apola_apple_touch_icon_152x152['url'])) : ?>
	<link rel="apple-touch-icon" sizes="152x152" href="<?php echo esc_url($apola_apple_touch_icon_152x152['url']); ?>">
	<?php endif; ?>
	<?php if(is_array($apola_apple_touch_icon_180x180) && isset($apola_apple_touch_icon_180x180['url']) && !empty($apola_apple_touch_icon_180x180['url'])) : ?>
	<link rel="apple-touch-icon" sizes="180x180" href="<?php echo esc_url($apola_apple_touch_icon_180x180['url']); ?>">
	<?php endif; ?>

	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>

<?php

	switch($apola_current_page_type) {
		case 'apola-portfolio-gallery':
			switch($apola_current_page_style) {
				case 'apola-slideshow':
					get_template_part('template-parts/header/header', sprintf(
						'%s-%s', preg_replace('/apola-header-/', '', $apola_header_type),
						preg_replace('/apola-/', '', $apola_current_page_style)
					));
				break;
				default:
					get_template_part('template-parts/header/header', preg_replace('/apola-header-/', '', $apola_header_type));
				break;
			}
		break;
		default:
			get_template_part('template-parts/header/header', preg_replace('/apola-header-/', '', $apola_header_type));
		break;
	}

/**
 * Hook for the prepend some content to the body.
 *
 * @hooked
 */
do_action( 'apola_body_prepend' );
?>
    <!-- - - - - - - - - - - - - - Page Wrapper - - - - - - - - - - - - - - - - -->
    <div class="apo-page">

		<?php
		/**
		 * Hook for the prepend some content to the page content.
		 *
		 * @hooked
		 */
		do_action( 'apola_page_prepend' );
		?>
		<div class="apo-page-content-wrap">
        	<div class="<?php echo esc_attr($ApolaHelper->getSanitizedHtmlClasses($apola_container_classes)); ?>">
