<?php
// Prevent the direct loading of the file
if ( ! defined( 'ABSPATH' ) ) {
	die( esc_html__('You cannot access this file directly', 'apola') );
}


/*	Blog Entry Categories
/* ---------------------------------------------------------------------- */
if ( !function_exists('apola_get_post_terms') ) {
    function apola_get_post_terms($id = null, $taxonomy = 'category', $excepts_ids = array()) {
        if( is_null($id) || !is_numeric($id)) return;

        $terms = get_the_terms(intval($id), $taxonomy);
		$terms_template = array();

		if(is_array($terms)) {
			$terms_template[] = '<ul class="apo-categories">';

			foreach($terms as $index => $term) {
				if(in_array($term->term_id, $excepts_ids)) continue;

				$term_link = get_term_link( $term );
				if( is_wp_error($term_link) ) continue;

	            $terms_template[] = '<li><a href="' .esc_url( $term_link ). '">' . esc_html( $term->name ) . '</a></li>';
			}

			$terms_template[] = '</ul>';
		}

        return implode("\r\t\n", $terms_template);
    }
}

if( !function_exists('apola_has_post_terms') ) {
	function apola_has_post_terms($id = null, $taxonomy = 'category', $excepts_ids = array()) {
		if(is_null($id) || !is_numeric($id)) return false;
		$terms = get_the_terms(intval($id), $taxonomy);

		if(!is_array($terms) || !count($terms)) return false;

		foreach($terms as $index => $term) {
			if(in_array($term->cat_ID, $excepts_ids)) unset($terms[$index]);
		}

		return count($terms);
	}
}

/* 	Isotope filter
/* --------------------------------------------------------------------- */
if( !function_exists('apola_display_filter') ) {
	function apola_display_filter($posts = array(), $filter_element_id, $default_caption_for_all_posts = 'All', $taxonomy = 'category', $post_id_key = null) {
		$terms = array();

		foreach($posts as $post) {
			if($post instanceof WP_Post) {
				$post_terms = get_the_terms($post->ID, $taxonomy);
			}
			elseif(is_array($post) && isset($post_id_key)) {
				$post_terms = get_the_terms($post[$post_id_key], $taxonomy);
			}


			if(isset($post_terms) && is_array($post_terms) && count($post_terms)) {
				foreach($post_terms as $term) {
					if(!in_array($term->slug, $terms)) array_push($terms, $term->slug);
				}
			}
		}

		?>
			<nav class="apo-filter-wrap">
				<ul id="<?php echo esc_attr($filter_element_id); ?>" class="apo-filter">
					<?php printf('<li><a href="#" class="apo-active" data-filter="%s">%s</a></li>', '*', esc_html($default_caption_for_all_posts)); ?>
					<?php
						if(count(array_unique($terms))) {
							foreach(array_unique($terms) as $item) {
								printf('<li><a href="#" data-filter="%s">%s</a></li>', '.' . $taxonomy . '-' . esc_attr($item), esc_html(ucfirst($item)));
							}
						}
					?>
				</ul>
			</nav>
		<?php
	}
}

/* 	Filter Hook for Comments
/* --------------------------------------------------------------------- */
if ( !function_exists('apola_output_comment')) {

	function apola_output_comment($comment, $args, $depth) {
		$GLOBALS['comment'] = $comment;

		$avatar = get_avatar($comment, 70, '', esc_html(get_comment_author()));

		$comment_classes = array('comment');

		if($avatar === false) array_push($comment_classes, 'comment-has-not-avatar');
	?>

		<li <?php comment_class(implode(' ', $comment_classes)); ?> id="comment-<?php echo comment_ID(); ?>">
			<div class="comment-body">
				<div class="comment-author vcard">
					<?php echo wp_kses_post($avatar); ?>
					<cite class="fn"><?php echo get_comment_author(); ?></cite>
				</div>
				<div class="comment-text"><?php comment_text(); ?></div>

				<div class="comment-helpful-links">
					<?php edit_comment_link(' ' . esc_html__('Edit', 'apola'),'  ','') ?>

					<?php echo get_comment_reply_link( array(
						'reply_text' => esc_html__('Reply', 'apola'),
						'depth' => $depth,
						'max_depth' => $args['max_depth']
					)); ?>
				</div>

				<?php if($comment->comment_approved == '0') : ?>
					<hr>
					<p><?php esc_html_e('Your comment is awaiting moderation.', 'apola'); ?></p>
				<?php endif; ?>
			</div>
		</li>

	<?php
	}
}

/* Reorder fields of the comment form
/* --------------------------------------------------------------------- */
if( !function_exists('apola_reorder_comment_form_fields') ) {
	function apola_reorder_comment_form_fields( $fields ) {
		$comment_field = $fields['comment'];
		unset( $fields['comment'] );
		$fields['comment'] = $comment_field;
		return $fields;
	}
}
add_filter( 'comment_form_fields', 'apola_reorder_comment_form_fields' );

/* 	Logo
/* --------------------------------------------------------------------- */
if( !function_exists('apola_logo') ) {
	function apola_logo($type = 'vertical', $color_scheme = 'dark') {
		global $Apola;

		$logo = $Apola->getThemeOption(sprintf('apola-logo-%s-%s', $type, $color_scheme));

		if(!is_array($logo)) {
			$logo = array(
				'url' => sprintf('%s/assets/images/logo-vertical-dark.png', APOLA_TEMPLATE_DIRECTORY_URI)
			);
		}
		?>

		<!-- - - - - - - - - - - - - - Logo - - - - - - - - - - - - - - - - -->
		<a href="<?php echo esc_url( home_url('/') ); ?>" class="apo-logo" title="<?php echo esc_attr( get_bloginfo('name', 'display') ); ?>" rel="home">
			<?php if( !empty( $logo['url'] ) ) : ?>
				<img src="<?php echo esc_url( $logo['url'] ); ?>" alt="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>">
			<?php else : ?>
				<?php bloginfo('name'); ?>
			<?php endif; ?>
		</a>
		<!-- - - - - - - - - - - - - - End of Logo - - - - - - - - - - - - - - - - -->
		<?php
	}
}

/* 	Page loader
/* --------------------------------------------------------------------- */
if( !function_exists('apola_show_page_loader') ) {
	function apola_show_page_loader() {
		global $Apola;

		$page_loader_state = $Apola->getThemeOption('page-loader-state', '0');
		$page_loader_logo = $Apola->getThemeOption('page-loader-logo');

		if($page_loader_state == '1') : ?>
			<div class="apo-preloader">
				<div class="apo-preloader-outer">
					<div class="apo-preloader-inner">
						<div class="apo-loader">
							<?php if(is_array($page_loader_logo) && isset($page_loader_logo['url']) && !empty($page_loader_logo['url'])) : ?>
								<img src="<?php echo esc_url($page_loader_logo['url']); ?>" alt="<?php esc_attr(get_bloginfo('name')); ?>">
							<?php else : ?>
								<img src="<?php echo sprintf('%s/assets/images/logo-vertical-dark.png', get_template_directory_uri()); ?>" alt="<?php esc_attr(get_bloginfo('name')); ?>">
							<?php endif; ?>
						</div>
					</div>
				</div>
			</div>
		<?php endif;
	}
}

add_action('apola_body_prepend', 'apola_show_page_loader');

/* 	Breadcrumbs
/* --------------------------------------------------------------------- */
if ( !function_exists('apola_breadcrumbs') ) {
	function apola_breadcrumbs() {
		if( function_exists( 'bcn_display' ) ) {
			echo '<div class="apo-breadcrumbs">';
			bcn_display();
			echo '</div>';
		}
	}
}


/* 	Pagination
/* --------------------------------------------------------------------- */
if(!function_exists('apola_pagination')) {
	function apola_pagination($args = array()) {
		if(isset($args['type'])) unset($args['type']);

		$defaults = array(
			'prev_next' => false,
			'type' => 'array'
		);

		$pagination = paginate_links(array_merge($defaults, $args));

		if(is_array($pagination)) : ?>
				<nav>
					<ul class="apo-pagination">
						<?php foreach($pagination as $page) : ?>
							<li><?php echo wp_kses($page, array(
								'span' => array(
									'style' => true,
									'class' => true
								),
								'a' => array(
									'href' => true,
									'class' => true,
									'style' => true
								)
							)); ?></li>
						<?php endforeach; ?>
					</ul>
				</nav>
		<?php endif;
	}
}

/*	Social links
/* ---------------------------------------------------------------------- */
if(!function_exists('apola_social_links')) {
	function apola_social_links($type = 'apo-style-1', $links = array('facebook', 'twitter', 'instagram', 'youtube', 'flickr')) {
		global $Apola;

		$links_prepared = array();

		foreach($links as $link) {
			$link_url = $Apola->getThemeOption(sprintf('apola-social-links-%s', $link));

			if(empty($link_url)) continue;

			$links_prepared[$link] = array(
				'url' => $link_url,
				'icon-class' => sprintf('fa-%s', $link)
			);
		}

		if(count($links_prepared)) :
		?>
			<ul class="apo-social-networks <?php echo sanitize_html_class($type); ?>">
				<?php foreach($links_prepared as $link_prepared) : ?>
					<li><a href="<?php echo esc_url($link_prepared['url']) ?>" target="_blank"><i class="fa <?php echo sanitize_html_class($link_prepared['icon-class']); ?>"></i></a></li>
				<?php endforeach; ?>
			</ul>
		<?php endif;
	}
}

/*	Navigation
/* ---------------------------------------------------------------------- */
if(!function_exists('apola_navigation')) {
	function apola_navigation($location = 'primary', $args = array()) {
		$defaults = array(
			'theme_location' => $location,
			'menu' => 'primary',
			'menu_class' => 'apo-navigation',
			'container' => 'nav',
			'container_class' => 'apo-navigation-container'
		);

		if(has_nav_menu($location)) {
			wp_nav_menu(array_merge($defaults, $args));
		}
	}
}

/*	Dump helper
/* ---------------------------------------------------------------------- */
if(!function_exists('apola_dump')) {
	function apola_dump($value) {
		echo "<pre>";
		if(is_array($value)) print_r($value);
		else var_dump($value);
		echo "</pre>";
	}
}

/*	AJAX handlers
/* ---------------------------------------------------------------------- */
if(!function_exists('apola_show_item_info_modal')) {
	function apola_show_item_info_modal() {
		check_ajax_referer('apola-ajax-nonce', 'AJAX_token');

		$data = $_GET['data'];

		if(!isset($data['post_type'])) {
			die();
		}

		ob_start();

		get_template_part('template-parts/modals/apola-modal-item-info', preg_replace('/apola-/', '', $data['post_type']));

		echo ob_get_clean();
		wp_die();

	}
}

if(wp_doing_ajax()) {
	add_action('wp_ajax_show_item_info_modal', 'apola_show_item_info_modal');
	add_action('wp_ajax_nopriv_show_item_info_modal', 'apola_show_item_info_modal');
}


/*  Checks whether post has pingbacks and trackbacks.
/* ---------------------------------------------------------------------- */
if( !function_exists( 'apola_has_post_pings' ) ) {
	function apola_has_post_pings( $post_id = null ) {
		if( is_null($post_id) ) return false;

		$comments = get_comments(array(
			'status' => 'approve',
			'type' => 'pings',
			'post_id' => $post_id
		));

		return boolval(count($comments));
	}
}

/*  Language switcher
/* ---------------------------------------------------------------------- */
if(!function_exists('apola_language_switcher')) {
	function apola_language_switcher() {
		$languages = apply_filters('wpml_active_languages', NULL, 'skip_missing=0');
		$active_language = null;

		if(count($languages)) : ?>
			<nav class="apo-language-switcher">
				<ul class="apo-language-switcher-list apo-language-switcher-list-top">
					<?php foreach($languages as $lang_code => $language) : ?>
						<?php if(!is_array($language)) continue; ?>

						<?php if(isset($language['active']) && boolval($language['active'])) {
							$active_language = $language;
							continue;
						} ?>

						<?php if(!isset($language['url']) || !isset($language['language_code'])) continue; ?>
						<li>
							<a href="<?php echo esc_url($language['url']); ?>"><?php echo esc_html(strtoupper($language['language_code'])); ?></a>
						</li>
					<?php endforeach; ?>
				</ul>

				<?php if(is_array($active_language) && isset($active_language['language_code'])) : ?>
					<button type="button" class="apo-language-switcher-current"><?php echo esc_html(strtoupper($active_language['language_code'])); ?></button>
				<?php endif; ?>
			</nav>
		<?php endif;
	}
}

/* 	Google fonts url
/* --------------------------------------------------------------------- */
if(!function_exists('apola_google_fonts_url')) {
	function apola_google_fonts_url(array $fonts_data = array(), array $charsets = array()) {
		$fonts_url = '';
		$font_family = array();

		if($fonts_data) {
			foreach($fonts_data as $font => $font_weights) {
				/* Translators: If there are characters in your language that are not supported
	            by chosen font(s), translate this to 'off'. Do not translate into your own language. */
				$font_state = sprintf( _x( 'on', '%s font: on or off', 'apola' ), $font );

				if ( 'off' !== $font_state ) {
	                $font_family[] = sprintf('%s:%s', $font, implode(',', $font_weights));
	            }
			}
		}

		if($font_family) {
			$fonts_url = add_query_arg(array(
				'family' => urlencode(implode('|', $font_family)),
				'subset' => urlencode(implode(',', $charsets))
			), 'https://fonts.googleapis.com/css');
		}

		return esc_url_raw($fonts_url);
	}
}

?>
