<?php
/**
 * The template file that is responsible to describe a gallery item markup.
 *
 * @package WordPress
 * @subpackage Apola
 * @since Apola 1.0
 */

// Prevent the direct loading of the file
if ( ! defined( 'ABSPATH' ) ) {
	die( esc_html__('You cannot access this file directly', 'apola') );
}

$apola_show_item_categories = get_query_var('apola-content-item-show-categories');
$apola_show_item_likes = get_query_var('apola-content-item-show-likes');
$apola_item_need_excerpt = get_query_var('apola-content-item-need-excerpt');
$apola_item = unserialize(get_query_var('apola-current-gallery-image'));
$apola_item_thumb_size = get_query_var('apola-item-thumb-size', 'apola-portfolio-thumb-horizontal');

$apola_item_ajax_data = array(
	'item_id'   		=> $apola_item['attach_id'],
	'post_type' 		=> 'apola-galleries',
	'parent_gallery_id' => $apola_item['parent_gallery_id'],
	'likes' 			=> $apola_item['apola-item-likes-count']
);
?>
<!-- - - - - - - - - - - - - - Project - - - - - - - - - - - - - -->

<article <?php post_class('apo-project'); ?>>
    <?php if(!empty(wp_get_attachment_image($apola_item['attach_id']))) : ?>
        <!-- - - - - - - - - - - - - - Project Media - - - - - - - - - - - - - -->
        <div class="apo-project-media"
             data-bg-img-src="<?php echo esc_url(wp_get_attachment_image_url($apola_item['attach_id'], $apola_item_thumb_size)); ?>">
			<?php if(!$apola_item_need_excerpt) : ?>
                <a href="#" class="apo-hover-btn apo-photo-info-invoker"
                            data-arctic-modal="true"
                            data-arctic-modal-type="ajax"
                            data-arctic-modal-ajax-action="show_item_info_modal"
                            data-arctic-modal-ajax-data="<?php echo esc_js(wp_json_encode($apola_item_ajax_data)); ?>">
            <?php endif; ?>
				<?php echo wp_get_attachment_image($apola_item['attach_id'], $apola_item_thumb_size); ?>
			<?php if(!$apola_item_need_excerpt) : ?>
                </a>
            <?php endif; ?>
        </div>
        <!-- - - - - - - - - - - - - - End of Project Media - - - - - - - - - - - - - -->
    <?php endif; ?>

    <!-- - - - - - - - - - - - - - Project Content - - - - - - - - - - - - - -->
    <div class="apo-project-content-wrap">
        <div class="apo-aligner-outer">
            <div class="apo-aligner-inner">
				<?php if((isset($apola_item['image-title']) && !empty($apola_item['image-title'])) || $apola_show_item_categories == 1) : ?>
	                <header class="apo-project-header">
	                    <?php if(isset($apola_item['image-title']) && !empty($apola_item['image-title'])) : ?>
	                        <h2 class="apo-project-title">
	                            <a href="#" class="apo-photo-info-invoker"
	                                        data-arctic-modal="true"
	                                        data-arctic-modal-type="ajax"
	                                        data-arctic-modal-ajax-action="show_item_info_modal"
	                                        data-arctic-modal-ajax-data="<?php echo esc_js(wp_json_encode($apola_item_ajax_data)); ?>">
	                                <?php echo esc_html($apola_item['image-title']); ?>
	                            </a>
	                        </h2>
	                    <?php endif; ?>

	                    <?php if($apola_show_item_categories == 1) : ?>
	                        <?php echo apola_get_post_terms($apola_item['parent_gallery_id'], 'apola-gallery-categories'); ?>
	                    <?php endif; ?>
	                </header>
				<?php endif; ?>

				<?php if($apola_item_need_excerpt && isset($apola_item['image-description']) && !empty($apola_item['image-description'])) : ?>
					<div class="apo-project-content">
						<?php echo esc_html($apola_item['image-description']); ?>
					</div>
				<?php endif; ?>

				<?php if($apola_show_item_likes == 1) : ?>
                    <footer class="apo-project-footer">
                        <ul class="apo-project-meta">
                            <li>
								<a href="#" class="apo-item-likes-btn"
									data-item-likes-data="<?php echo esc_attr(wp_json_encode($apola_item_ajax_data)); ?>">
									<i class="icon-heart"></i>
									<span class="apo-item-likes"><?php echo esc_html(intval($apola_item_ajax_data['likes'])); ?></span>
								</a>
							</li>
                        </ul>
                    </footer>
				<?php endif; ?>
            </div>
        </div>
    </div>
    <!-- - - - - - - - - - - - - - End of Project Content - - - - - - - - - - - - - -->


	<span class="apo-project-triangle"></span>
</article>
<!-- - - - - - - - - - - - - - End of Project - - - - - - - - - - - - - -->
