<?php
/**
* The template for displaying images of single gallery within a slideshow.
*
* @package WordPress
* @subpackage Apola
* @since Apola 1.0
*/

// Prevent the direct loading of the file
if ( ! defined( 'ABSPATH' ) ) {
	die( esc_html__('You cannot access this file directly', 'apola') );
}

global $Apola;
$ApolaHelper = $Apola->helper();

$ApolaPostsRepository = new ApolaGalleryRepository();
$ApolaPostLiker = new ApolaPostLiker($ApolaPostsRepository);
$apola_gallery_builder = unserialize(get_query_var('apola-queried-gallery-builder', array()));

$apola_items = $ApolaPostsRepository->in(array(get_the_ID()))->get();
$apola_header_position_whitelist = array('apo-header-vertical', 'apo-header-horizontal');
$apola_header_color_scheme = isset($apola_gallery_builder['sliders']['single-page-header-color-scheme']) ? $apola_gallery_builder['sliders']['single-page-header-color-scheme'] : 'apo-header-dark';
$apola_header_classes = array();


// Filtering options
if(isset($apola_gallery_builder['sliders']['single-page-header-position']) && $apola_gallery_builder['sliders']['single-page-header-position'] == 'apo-header-bottom') {
	array_push($apola_header_classes, 'apo-header-bottom');
	$apola_is_vertical_header = false;
}
else {
	array_push($apola_header_classes, 'apo-style-2');
	array_push($apola_header_classes, 'apo-header-vertical');
	$apola_is_vertical_header = true;
}

if(!isset($apola_gallery_builder['sliders']['single-page-slide-duration']) || !is_numeric($apola_gallery_builder['sliders']['single-page-slide-duration'])) {
	$apola_gallery_builder['sliders']['single-page-slide-duration'] = 500;
}

if(!isset($apola_gallery_builder['sliders']['single-page-slide-transition'])) {
	$apola_gallery_builder['sliders']['single-page-slide-transition'] = 'fade';
}

array_push($apola_header_classes, $apola_header_color_scheme);
?>


<!-- - - - - - - - - - - - - - Site Header - - - - - - - - - - - - - - - - -->
<header id="apo-header" class="apo-header <?php echo esc_attr($ApolaHelper->getSanitizedHtmlClasses($apola_header_classes)); ?>">
	<div class="apo-header-section">
		<div class="apo-header-component-first">
			<div class="apo-header-items">
                <div class="apo-header-item">
                    <!-- - - - - - - - - - - - - - Navigation Button - - - - - - - - - - - - - -->
                    <div type="button" data-arctic-modal="#modal-nav" class="apo-header-button hamburger hamburger--emphatic apo-hamburger-clickable">
                        <span class="hamburger-box">
                            <span class="hamburger-inner"></span>
                        </span>
                    </div>
                    <!-- - - - - - - - - - - - - - End of Navigation Button - - - - - - - - - - - - - -->

                    <!-- - - - - - - - - - - - - - Navigation Popup - - - - - - - - - - - - - - - - -->
                    <div class="apo-d-none">
                        <div id="modal-nav" class="apo-modal apo-modal-fullscreen-nav">
                            <div class="container">
                                <div class="apo-section">
                                    <?php apola_navigation('primary', array(
										'container_class' => 'apo-navigation-vertical-container',
										'menu_class' => 'apo-navigation-vertical'
                                    )); ?>

                                    <?php get_search_form(); ?>
                                </div>
                            </div>

                            <div class="arctic-modal-close-container">
                                <button type="button" class="apo-close-btn arcticmodal-close"><i class="icon icon-cross"></i> <?php esc_html_e('Close', 'apola'); ?></button>
                            </div>
                        </div>
                    </div>
                    <!-- - - - - - - - - - - - - - End of Navigation Popup - - - - - - - - - - - - - - - - -->
                </div>

				<div class="apo-header-item">
					<?php apola_logo('vertical', ($apola_header_color_scheme == 'apo-header-dark' ? 'light' : 'dark')); ?>
				</div>
			</div>
		</div>
		<div class="apo-header-component-middle">
			<div class="apo-header-items">
				<?php if(is_array($apola_items) && count($apola_items)) : ?>
                    <div class="apo-header-item">
                        <!-- - - - - - - - - - - - - - Slide Thumbnails - - - - - - - - - - - - - -->
                        <nav class="apo-slider-thumbs swiper-container <?php echo sanitize_html_class($apola_is_vertical_header ? 'apo-slider-thumbs-vr' : 'apo-slider-thumbs-hr'); ?>">
                            <button class="swiper-button-prev">
								<?php if($apola_is_vertical_header) : ?>
	                                <i class="icon icon-chevron-up"></i>
								<?php else : ?>
									<i class="icon icon-chevron-left"></i>
								<?php endif; ?>
                            </button>

                            <div class="swiper-wrapper">
                                <?php foreach($apola_items as $apola_item) : ?>
                                    <div class="swiper-slide">
										<?php if(is_array($apola_item) && isset($apola_item['attach_id'])) : ?>
											<div class="apo-slider-thumb" data-bg-img-src="<?php echo esc_attr(wp_get_attachment_image_url($apola_item['attach_id'], array(150, 150))); ?>"></div>
										<?php endif; ?>
                                    </div>
                                <?php endforeach; ?>
                            </div>

                            <button class="swiper-button-next">
								<?php if($apola_is_vertical_header) : ?>
	                                <i class="icon icon-chevron-down"></i>
								<?php else : ?>
									<i class="icon icon-chevron-right"></i>
								<?php endif; ?>
                            </button>
                        </nav>
                        <!-- - - - - - - - - - - - - - End of Slider Thumbnails - - - - - - - - - - - - - -->
                    </div>
				<?php endif; ?>
			</div>
		</div>
		<div class="apo-header-component-last">
			<div class="apo-header-items">
                <?php if(is_array($apola_items) && count($apola_items)) :
					$apola_first_post = $apola_items[0];
					$apola_first_item_ajax_data = array(
						'post_type' => 'apola-galleries'
					);

					if(is_array($apola_first_post) && isset($apola_first_post['attach_id'])) {
						$apola_first_item_ajax_data['item_id'] =  $apola_first_post['attach_id'];

						if(isset($apola_first_post['parent_gallery_id'])) {
							$apola_first_item_ajax_data['parent_gallery_id'] = $apola_first_post['parent_gallery_id'];
						}
					}

					if(isset($apola_first_item_ajax_data['item_id']) && is_numeric($apola_first_item_ajax_data['item_id'])) {
						$apola_first_item_ajax_data['likes'] = $ApolaPostLiker->getLikesCount($apola_first_item_ajax_data['item_id']);
					}
                ?>
                    <div class="apo-header-item">
                        <!-- - - - - - - - - - - - - - Like Button - - - - - - - - - - - - - -->
                        <button class="apo-hover-btn apo-item-likes-btn"
                                type="button"
                                data-item-likes-data="<?php echo esc_attr(wp_json_encode($apola_first_item_ajax_data)); ?>">
                            <span class="apo-hover-btn-tooltip apo-item-likes"><?php echo esc_html($apola_first_item_ajax_data['likes']); ?></span>
                            <i class="icon icon-heart"></i>
                        </button>
                        <!-- - - - - - - - - - - - - - End of Like Button - - - - - - - - - - - - - -->
                    </div>

                    <div class="apo-header-item apo-fullscreen-control">
                        <!-- - - - - - - - - - - - - - Full Screen Button - - - - - - - - - - - - - -->
                        <button type="button" class="apo-hover-btn">
                            <i class="icon icon-expand"></i>
                        </button>
                        <!-- - - - - - - - - - - - - - End of Full Screen Button - - - - - - - - - - - - - -->
                    </div>

                    <div class="apo-header-item">
                        <!-- - - - - - - - - - - - - - Info Button - - - - - - - - - - - - - -->
                        <button type="button"
                               class="apo-hover-btn apo-modal-info-invoker"
                               data-arctic-modal="true"
                               data-arctic-modal-type="ajax"
                               data-arctic-modal-ajax-action="show_item_info_modal"
                               data-arctic-modal-ajax-data="<?php echo esc_attr(wp_json_encode($apola_first_item_ajax_data)); ?>">
                           <i class="icon icon-menu-circle"></i>
                       </button>
                        <!-- - - - - - - - - - - - - - End of Info Button - - - - - - - - - - - - - -->
                    </div>
                <?php endif; ?>
			</div>
		</div>
	</div>
</header>
<!-- - - - - - - - - - - - - - End of Site Header - - - - - - - - - - - - - - - - -->

<?php if($apola_items) : ?>
<div class="apo-revslider-theme">
    <!-- - - - - - - - - - - - - - Revolution Slider - - - - - - - - - - - - - -->
    <div class="rev_slider_wrapper fullscreen-container">
        <div id="rev-slider-1" class="rev_slider fullscreenbanner apo-revslider-theme">
            <ul>
                <?php foreach($apola_items as $apola_item) :
                    $apola_item_ajax_data = array(
                        'post_type' => 'apola-galleries'
                    );

                    if(is_array($apola_item) && isset($apola_item['attach_id'])) {
                        $apola_post_id = $apola_item['attach_id'];
                        $apola_item_ajax_data['item_id'] = $apola_item['attach_id'];

                        if(isset($apola_item['parent_gallery_id'])) {
                            $apola_item_ajax_data['parent_gallery_id'] = $apola_item['parent_gallery_id'];
                        }
                    }

                    if(isset($apola_item_ajax_data['item_id']) && is_numeric($apola_item_ajax_data['item_id'])) {
                        $apola_item_ajax_data['likes'] = $ApolaPostLiker->getLikesCount($apola_item_ajax_data['item_id']);
                    }
                ?>
                    <?php if(isset($apola_item_ajax_data['item_id'])) : ?>
                        <li data-transition="<?php echo esc_attr($apola_gallery_builder['sliders']['single-page-slide-transition']); ?>"
                            data-speed="<?php echo esc_attr($apola_gallery_builder['sliders']['single-page-slide-transition']); ?>"
                            data-post-data="<?php echo esc_attr(wp_json_encode($apola_item_ajax_data)); ?>">
                            <?php echo wp_get_attachment_image($apola_item_ajax_data['item_id'], 'apola-full-screen-thumb'); ?>
                        </li>
                    <?php endif; ?>
                <?php endforeach; ?>
            </ul>

            <!-- - - - - - - - - - - - - - Slider Controls - - - - - - - - - - - - - -->
            <div class="apo-revslider-controls apo-right">
                <div class="apo-revslider-controls-item">
                    <div class="apo-revslider-theme-nav-prev">
                        <div class="apo-revslider-control-title"><?php esc_html_e('Prev', 'apola'); ?></div>
                        <i class="apola-icon-prev"></i>
                    </div>
                </div>

                <div class="apo-revslider-controls-item apo-playing">
                    <div class="apo-revslider-control-pause">
                        <div class="apo-revslider-control-title"><?php esc_html_e('Pause', 'apola'); ?></div>
                        <i class="apola-icon-pause"></i>
                    </div>

                    <div class="apo-revslider-control-play">
                        <div class="apo-revslider-control-title"><?php esc_html_e('Play', 'apola'); ?></div>
                        <i class="apola-icon-play"></i>
                    </div>
                </div>

                <div class="apo-revslider-controls-item">
                    <div class="apo-revslider-theme-nav-next">
                        <div class="apo-revslider-control-title"><?php esc_html_e('Next', 'apola'); ?></div>
                        <i class="apola-icon-next"></i>
                    </div>
                </div>
            </div>
            <!-- - - - - - - - - - - - - - End of Slider Controls - - - - - - - - - - - - - -->
        </div>

        <div class="apo-slider-fullscreen-controls <?php echo sanitize_html_class($apola_header_color_scheme == 'apo-header-dark' ? 'apo-fullscreen-controls-dark' : 'apo-fullscreen-controls-light'); ?>">
            <div class="container">
                <div class="apo-hr-controls">
                    <div class="apo-hr-controls-component-first">
                        <div class="apo-hr-controls-items">
                            <div class="apo-hr-controls-item">
                                <?php if(is_array($apola_items) && count($apola_items)) :
                                    $apola_first_post = $apola_items[0];
                                    $apola_first_item_ajax_data = array(
                                        'post_type' => 'apola-galleries'
                                    );

                                    if(is_array($apola_first_post) && isset($apola_first_post['attach_id'])) {
                                        $apola_first_item_ajax_data['item_id'] = $apola_first_post['attach_id'];

                                        if(isset($apola_first_post['parent_gallery_id'])) {
                                            $apola_first_item_ajax_data['parent_gallery_id'] = $apola_first_post['parent_gallery_id'];
                                        }
                                    }

                                    if(isset($apola_first_item_ajax_data['item_id']) && is_numeric($apola_first_item_ajax_data['item_id'])) {
                                        $apola_first_item_ajax_data['likes'] = $ApolaPostLiker->getLikesCount($apola_first_item_ajax_data['item_id']);
                                    }
                                ?>

                                <!-- - - - - - - - - - - - - - Like Button - - - - - - - - - - - - - -->
                                <button class="apo-hover-btn apo-item-likes-btn"
                                        type="button"
                                        data-item-likes-data="<?php echo esc_attr(wp_json_encode($apola_first_item_ajax_data)); ?>">
                                    <span class="apo-hover-btn-tooltip apo-item-likes"><?php echo esc_html($apola_first_item_ajax_data['likes']); ?></span>
                                    <i class="icon icon-heart"></i>
                                </button>
                                <!-- - - - - - - - - - - - - - End of Like Button - - - - - - - - - - - - - -->
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>

                    <div class="apo-hr-controls-component-middle">
                        <div class="apo-hr-controls-items">
                            <div class="apo-hr-controls-item">
                                <button type="button" class="apo-fullscreen-control-close">
                                    <i class="icon icon-cross"></i><?php esc_html_e('Close', 'apola'); ?>
                                </button>
                            </div>
                        </div>
                    </div>

                    <div class="apo-hr-controls-component-last">
                        <div class="apo-hr-controls-items">
                            <div class="apo-hr-controls-item">
                                <!-- - - - - - - - - - - - - - Slider Controls - - - - - - - - - - - - - -->
                                <div class="apo-revslider-controls apo-right">
                                    <div class="apo-revslider-controls-item">
                                        <div class="apo-revslider-theme-nav-prev">
                                            <div class="apo-revslider-control-title"><?php esc_html_e('Prev', 'apola'); ?></div>
                                            <i class="apola-icon-prev"></i>
                                        </div>
                                    </div>

                                    <div class="apo-revslider-controls-item apo-playing">
                                        <div class="apo-revslider-control-pause">
                                            <div class="apo-revslider-control-title"><?php esc_html_e('Pause', 'apola'); ?></div>
                                            <i class="apola-icon-pause"></i>
                                        </div>

                                        <div class="apo-revslider-control-play">
                                            <div class="apo-revslider-control-title"><?php esc_html_e('Play', 'apola'); ?></div>
                                            <i class="apola-icon-play"></i>
                                        </div>
                                    </div>

                                    <div class="apo-revslider-controls-item">
                                        <div class="apo-revslider-theme-nav-next">
                                            <div class="apo-revslider-control-title"><?php esc_html_e('Next', 'apola'); ?></div>
                                            <i class="apola-icon-next"></i>
                                        </div>
                                    </div>
                                </div>
                                <!-- - - - - - - - - - - - - - End of Slider Controls - - - - - - - - - - - - - -->
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
<?php endif; ?>
