<?php
/**
* The template file that responsible to display archive page of galleries.
*
* @package WordPress
* @subpackage Apola
* @since Apola 1.0
*/

// Prevent the direct loading of the file
if ( ! defined( 'ABSPATH' ) ) {
	die( esc_html__('You cannot access this file directly', 'apola') );
}

global $Apola;
$ApolaHelper = $Apola->helper();

$apola_query_paged = intval(isset($_GET['pagenum']) ? $_GET['pagenum'] : 1);
$apola_query_limit = intval(get_option('posts_per_page'));

$ApolaPostsRepository = new ApolaGalleryRepository();
$apola_posts = $ApolaPostsRepository->fromCategories(get_query_var('apola-gallery-categories'))
									->offset(($apola_query_paged - 1) * $apola_query_limit)
                                    ->limit($apola_query_limit)
                                    ->get();

set_query_var('apola-content-item-show-categories', 1);
set_query_var('apola-content-item-show-likes', 1);
?>

<?php if(is_array($apola_posts) && count($apola_posts)) : $apola_loop_counter = 0; ?>
    <!-- - - - - - - - - - - - - - Main Content - - - - - - - - - - - - - - - - -->
    <main class="apo-section apo-full-width">
        <!-- - - - - - - - - - - - - - Isotope Container - - - - - - - - - - - - - -->
        <div class="apo-isotope apo-portfolio-container apo-style-3 apo-cols-3"
             data-isotope-layout="masonry">
            <div class="grid-sizer"></div>
            <?php foreach($apola_posts as $apola_item) : ?>
                <div class="<?php echo esc_attr($ApolaHelper->getSanitizedHtmlClasses(get_post_class('apo-item', $apola_item['parent_gallery_id']))); ?>">
                    <?php
                        set_query_var('apola-current-gallery-image', serialize($apola_item));
						set_query_var('apola-item-thumb-size', sprintf('apola-portfolio-thumb-%s', ($apola_loop_counter % 2 == 0) ? 'vertical' : 'horizontal'));
                        get_template_part('template-parts/apola-galleries/apola-galleries', 'post');
                    ?>
                </div>
            <?php $apola_loop_counter++; endforeach; ?>
        </div>
        <!-- - - - - - - - - - - - - - End of Isotope Container - - - - - - - - - - - - - -->
    </main>
    <!-- - - - - - - - - - - - - - End of Main Content - - - - - - - - - - - - - - - - -->

    <!-- - - - - - - - - - - - - - Pagination - - - - - - - - - - - - - - - - -->
    <div class="apo-page-controls">
        <?php apola_pagination(array(
            'total'   => ceil( count($ApolaPostsRepository) / $apola_query_limit ),
            'current' => $apola_query_paged,
			'format' => '?pagenum=%#%',
            'prev_next' => false,
            'end_size' => 1
        )); ?>
    </div>
    <!-- - - - - - - - - - - - - - End of Pagination - - - - - - - - - - - - - - - - -->
<?php else : ?>
    <div class="apo-section apo-section-no-content">
        <?php get_template_part('template-parts/content', 'none'); ?>
    </div>
<?php endif; ?>
