<?php
/**
 * The template file that is responsible to describe a project element markup.
 *
 * @package WordPress
 * @subpackage Apola
 * @since Apola 1.0
 */

// Prevent the direct loading of the file
if ( ! defined( 'ABSPATH' ) ) {
	die( esc_html__('You cannot access this file directly', 'apola') );
}

$apola_show_item_categories = get_query_var('apola-content-item-show-categories');
$apola_show_item_likes = get_query_var('apola-content-item-show-likes');
$apola_item_need_excerpt = get_query_var('apola-content-item-need-excerpt');
$apola_item_thumb_size = get_query_var('apola-item-thumb-size', 'apola-portfolio-thumb-horizontal');

$apola_item_ajax_data = array(
	'item_id'   => get_the_ID(),
	'post_type' => 'apola-portfolio',
	'likes'     => get_post_meta(get_the_ID(), 'apola-item-likes-count', true)
);
?>
<!-- - - - - - - - - - - - - - Project - - - - - - - - - - - - - -->

<article <?php post_class(has_post_thumbnail() ? 'apo-project' : 'apo-project apo-project-without-thumb'); ?>>
    <?php if(has_post_thumbnail()) : ?>
        <!-- - - - - - - - - - - - - - Project Media - - - - - - - - - - - - - -->
        <div class="apo-project-media" data-bg-img-src="<?php echo esc_url(get_the_post_thumbnail_url(get_the_ID(), $apola_item_thumb_size)); ?>">
			<?php if(!$apola_item_need_excerpt) : ?><a href="<?php the_permalink(); ?>"><?php endif; ?>
				<?php the_post_thumbnail($apola_item_thumb_size); ?>
			<?php if(!$apola_item_need_excerpt) : ?></a><?php endif; ?>
        </div>
        <!-- - - - - - - - - - - - - - End of Project Media - - - - - - - - - - - - - -->
    <?php endif; ?>

    <!-- - - - - - - - - - - - - - Project Content - - - - - - - - - - - - - -->
    <div class="apo-project-content-wrap">
        <div class="apo-aligner-outer">
            <div class="apo-aligner-inner">
                <header class="apo-project-header">
                    <h2 class="apo-project-title">
                        <a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
                    </h2>

                    <?php if($apola_show_item_categories == 1 && apola_has_post_terms(get_the_ID(), 'apola-portfolio-categories')) : ?>
                        <?php echo apola_get_post_terms(get_the_ID(), 'apola-portfolio-categories'); ?>
                    <?php endif; ?>
                </header>

				<?php if($apola_item_need_excerpt && !empty(get_the_excerpt())) : ?>
					<div class="apo-project-content">
						<?php the_excerpt(); ?>
					</div>
				<?php endif; ?>

				<?php if($apola_show_item_likes == 1) : ?>
                    <footer class="apo-project-footer">
                        <ul class="apo-project-meta">
                            <li>
								<a href="#" class="apo-item-likes-btn"
								   data-item-likes-data="<?php echo esc_attr(wp_json_encode($apola_item_ajax_data)); ?>">
									<i class="icon-heart"></i>
									<span class="apo-item-likes"><?php echo esc_html(intval($apola_item_ajax_data['likes'])); ?></span>
								</a>
							</li>
                        </ul>
                    </footer>
				<?php endif; ?>
            </div>
        </div>
    </div>
    <!-- - - - - - - - - - - - - - End of Project Content - - - - - - - - - - - - - -->
	<span class="apo-project-triangle"></span>
</article>
<!-- - - - - - - - - - - - - - End of Project - - - - - - - - - - - - - -->
