<?php
/**
* The template for displaying a single portfolio project.
*
* @package WordPress
* @subpackage Apola
* @since Apola 1.0
*/

// Prevent the direct loading of the file
if ( ! defined( 'ABSPATH' ) ) {
	die( esc_html__('You cannot access this file directly', 'apola') );
}

global $Apola;
$apola_project_meta = $Apola->getThemeOption('apola-project-meta', array());

$apola_project_has_social_profiles = (!empty(get_post_meta(get_the_ID(), 'apola-project-facebook', true)) ||
                                     !empty(get_post_meta(get_the_ID(), 'apola-project-youtube', true)) ||
                                     !empty(get_post_meta(get_the_ID(), 'apola-project-twitter', true)) ||
                                     !empty(get_post_meta(get_the_ID(), 'apola-project-google-plus', true)) ||
                                     !empty(get_post_meta(get_the_ID(), 'apola-project-instagram', true)));

$apola_project_gallery = get_post_meta(get_the_ID(), 'apola_gallery_builder', true);

get_header(); ?>

<?php if(have_posts()) : ?>
    <?php while(have_posts()) : the_post(); ?>
        <!-- - - - - - - - - - - - - - Content Section - - - - - - - - - - - - - -->
        <div class="apo-section apo-full-width" style="padding-top: 0;padding-bottom: 0;">
            <main id="apo-fixed-content-fixed-col" class="apo-fixed-content-fixed-col">
                <h2><?php the_title(); ?></h2>

                <?php the_content(); ?>

				<?php wp_link_pages( array(
					'before' => '<div class="apo-page-links"><span class="apo-page-links-title">' . esc_html__( 'Pages:', 'apola' ) . '</span>',
					'after' => '</div>',
					'link_before' => '<span>',
					'link_after' => '</span>'
				) ); ?>

                <hr class="apo-divider-small apo-divider-thin"/>

                <dl class="apo-project-details">
                    <?php if(apola_has_post_terms(get_the_ID(), 'apola-portfolio-categories')) : ?>
                        <dt><?php esc_html_e('Categories', 'apola'); ?>:</dt>
                        <dd><?php echo apola_get_post_terms(get_the_ID(), 'apola-portfolio-categories'); ?></dd>
                    <?php endif; ?>

                    <?php if(is_array($apola_project_meta) && count($apola_project_meta)) : ?>
                        <?php foreach($apola_project_meta as $project_meta) : ?>
                            <dt><?php echo esc_html($project_meta[0]); ?></dt>
                            <dd><?php echo esc_html($project_meta[1]); ?></dd>
                        <?php endforeach; ?>
                    <?php endif; ?>
                </dl>

                <?php if($apola_project_has_social_profiles) : ?>
                    <!-- - - - - - - - - - - - - - Social networks - - - - - - - - - - - - - -->
                    <ul class="apo-social-networks apo-style-1">
                        <?php if(!empty(get_post_meta(get_the_ID(), 'apola-project-facebook', true))) : ?>
                            <li>
                                <a href="<?php echo esc_url(get_post_meta(get_the_ID(), 'apola-project-facebook', true)); ?>">
                                    <i class="fa fa-facebook"></i>
                                </a>
                            </li>
                        <?php endif; ?>
                        <?php if(!empty(get_post_meta(get_the_ID(), 'apola-project-youtube', true))) : ?>
                            <li>
                                <a href="<?php echo esc_url(get_post_meta(get_the_ID(), 'apola-project-youtube', true)); ?>">
                                    <i class="fa fa-youtube-play"></i>
                                </a>
                            </li>
                        <?php endif; ?>
                        <?php if(!empty(get_post_meta(get_the_ID(), 'apola-project-twitter', true))) : ?>
                            <li>
                                <a href="<?php echo esc_url(get_post_meta(get_the_ID(), 'apola-project-twitter', true)); ?>">
                                    <i class="fa fa-twitter"></i>
                                </a>
                            </li>
                        <?php endif; ?>
                        <?php if(!empty(get_post_meta(get_the_ID(), 'apola-project-google-plus', true))) : ?>
                            <li>
                                <a href="<?php echo esc_url(get_post_meta(get_the_ID(), 'apola-project-google-plus', true)); ?>">
                                    <i class="fa fa-google"></i>
                                </a>
                            </li>
                        <?php endif; ?>
                        <?php if(!empty(get_post_meta(get_the_ID(), 'apola-project-instagram', true))) : ?>
                            <li>
                                <a href="<?php echo esc_url(get_post_meta(get_the_ID(), 'apola-project-instagram', true)); ?>">
                                    <i class="fa fa-instagram"></i>
                                </a>
                            </li>
                        <?php endif; ?>
                    </ul>
                    <!-- - - - - - - - - - - - - - End of Social networks - - - - - - - - - - - - - -->
                <?php endif; ?>

				<?php if(comments_open()) : ?>
					<?php comments_template(); ?>
				<?php endif; ?>
            </main>

            <!-- - - - - - - - - - - - - - Images Column - - - - - - - - - - - - - -->
            <div class="apo-fixed-content-scroll-col">
                <div class="apo-project-images">
                    <?php the_post_thumbnail('apola-portfolio-thumb-vertical'); ?>
					<?php if(isset($apola_project_gallery['sliders']) && isset($apola_project_gallery['sliders']['slides']) && is_array($apola_project_gallery['sliders']['slides']) && count($apola_project_gallery['sliders']['slides'])) : ?>
						<?php foreach($apola_project_gallery['sliders']['slides'] as $image) : ?>
							<?php echo wp_get_attachment_image($image['attach_id'], 'apola-portfolio-thumb-vertical'); ?>
						<?php endforeach; ?>
					<?php endif; ?>
                </div>
            </div>
            <!-- - - - - - - - - - - - - - End of Images Column - - - - - - - - - - - - - -->
        </div>
        <!-- - - - - - - - - - - - - - End of Content Section - - - - - - - - - - - - - -->
    <?php endwhile; ?>
<?php else : ?>
    <?php get_template_part('template-parts/content', 'none'); ?>
<?php endif; ?>
<?php get_footer(); ?>
