<?php
/**
* The template for displaying a single team member page.
*
* @package WordPress
* @subpackage Apola
* @since Apola 1.0
*/

// Prevent the direct loading of the file
if ( ! defined( 'ABSPATH' ) ) {
	die( esc_html__('You cannot access this file directly', 'apola') );
}

get_header(); ?>

<div class="apo-section">
	<?php if(have_posts()) : ?>
		<?php while( have_posts() ) : the_post();
			$apola_team_member_has_social_profiles = (!empty(get_post_meta(get_the_ID(), 'apola-team-member-facebook', true)) ||
													 !empty(get_post_meta(get_the_ID(), 'apola-team-member-youtube', true)) ||
													 !empty(get_post_meta(get_the_ID(), 'apola-team-member-twitter', true)) ||
													 !empty(get_post_meta(get_the_ID(), 'apola-team-member-google-plus', true)) ||
													 !empty(get_post_meta(get_the_ID(), 'apola-team-member-instagram', true)));
		?>
	        <!-- - - - - - - - - - - - - - Main Content - - - - - - - - - - - - - - - - -->
			<main class="apo-section apo-section-thin apo-medium">
				<div class="apo-section">
			        <!-- - - - - - - - - - - - - - Single Entry - - - - - - - - - - - - - - - - -->
			        <article <?php post_class('apo-entry apo-single apo-team-member-single') ?>>
			            <?php if( has_post_thumbnail() && !post_password_required() ) : ?>
			                <!-- - - - - - - - - - - - - - Entry Media - - - - - - - - - - - - - - - - -->
			                <div class="apo-entry-media">
			                    <?php the_post_thumbnail('apola-team-member-thumb'); ?>
			                </div>
			                <!-- - - - - - - - - - - - - - End of Entry Media - - - - - - - - - - - - - - - - -->
			            <?php endif; ?>

			            <!-- - - - - - - - - - - - - - Entry Content - - - - - - - - - - - - - - - - -->
			            <div class="apo-entry-content-wrap">
			                <header class="apo-entry-header">
			                    <h2 class="apo-entry-title"><?php the_title(); ?></h2>

			                    <ul class="apo-entry-meta">
	                                <?php if(!empty(get_post_meta(get_the_ID(), 'apola-team-member-position', true))) : ?>
	                                    <li><?php esc_html_e('Position:', 'apola'); ?> <span class="apo-entry-meta-highlighted"><?php echo esc_html(get_post_meta(get_the_ID(), 'apola-team-member-position', true)); ?></span></li>
	                                <?php endif; ?>
			                        <?php if(apola_has_post_terms(get_the_ID(), 'apola-tm-categories')) : ?>
			                            <li><?php esc_html_e('Categories:', 'apola'); ?> <?php echo apola_get_post_terms(get_the_ID(), 'apola-tm-categories'); ?></li>
			                        <?php endif; ?>
			                    </ul>

	                            <?php if($apola_team_member_has_social_profiles) : ?>
	                                <ul class="apo-social-networks">
	                                    <?php if(!empty(get_post_meta(get_the_ID(), 'apola-team-member-facebook', true))) : ?>
	                                        <li>
	                                            <a href="<?php echo esc_url(get_post_meta(get_the_ID(), 'apola-team-member-facebook', true)); ?>">
	                                                <i class="fa fa-facebook"></i>
	                                            </a>
	                                        </li>
	                                    <?php endif; ?>
	                                    <?php if(!empty(get_post_meta(get_the_ID(), 'apola-team-member-youtube', true))) : ?>
	                                        <li>
	                                            <a href="<?php echo esc_url(get_post_meta(get_the_ID(), 'apola-team-member-youtube', true)); ?>">
	                                                <i class="fa fa-youtube-play"></i>
	                                            </a>
	                                        </li>
	                                    <?php endif; ?>
	                                    <?php if(!empty(get_post_meta(get_the_ID(), 'apola-team-member-twitter', true))) : ?>
	                                        <li>
	                                            <a href="<?php echo esc_url(get_post_meta(get_the_ID(), 'apola-team-member-twitter', true)); ?>">
	                                                <i class="fa fa-twitter"></i>
	                                            </a>
	                                        </li>
	                                    <?php endif; ?>
	                                    <?php if(!empty(get_post_meta(get_the_ID(), 'apola-team-member-google-plus', true))) : ?>
	                                        <li>
	                                            <a href="<?php echo esc_url(get_post_meta(get_the_ID(), 'apola-team-member-google-plus', true)); ?>">
	                                                <i class="fa fa-google"></i>
	                                            </a>
	                                        </li>
	                                    <?php endif; ?>
	                                    <?php if(!empty(get_post_meta(get_the_ID(), 'apola-team-member-instagram', true))) : ?>
	                                        <li>
	                                            <a href="<?php echo esc_url(get_post_meta(get_the_ID(), 'apola-team-member-instagram', true)); ?>">
	                                                <i class="fa fa-instagram"></i>
	                                            </a>
	                                        </li>
	                                    <?php endif; ?>
	                                </ul>
	                            <?php endif; ?>
			                </header>

			                <div class="apo-entry-content">
			                    <?php
			                        the_content();
			                        wp_link_pages( array(
			                            'before' => '<div class="apo-page-links"><span class="apo-page-links-title">' . esc_html__( 'Pages:', 'apola' ) . '</span>',
			                            'after' => '</div>',
			                            'link_before' => '<span>',
			                            'link_after' => '</span>'
			                        ) );
			                    ?>
			                </div>
			            </div>
			        </article>
			        <!-- - - - - - - - - - - - - - End of Single Entry - - - - - - - - - - - - - - - - -->
				</div>

				<div class="apo-section apo-align-center">
		            <a href="<?php echo esc_url( get_post_type_archive_link( get_post_type() ) ); ?>" class="apo-btn" role="button"><?php esc_html_e('View all team members', 'apola'); ?></a>
		        </div>

	                <?php if(comments_open()) : ?>
	    				<?php comments_template(); ?>
	                <?php endif; ?>
		    </main>
		<?php endwhile; ?>
        <!-- - - - - - - - - - - - - - End of Main Content - - - - - - - - - - - - - - - - -->
	<?php else : ?>
		<?php get_template_part('template-parts/content', 'none'); ?>
	<?php endif; ?>
</div>
<?php get_footer(); ?>
