<?php
/**
* The template file that describes vertical header markup
*
* @package WordPress
* @subpackage Apola
* @since Apola 1.0
*/

// Prevent the direct loading of the file
if ( ! defined( 'ABSPATH' ) ) {
	die( esc_html__('You cannot access this file directly', 'apola') );
}

global $Apola;

$ApolaHelper = $Apola->helper();
$apola_header_classes = array();
$apola_hidden_column_classes = array();

$apola_header_color_scheme = $Apola->getThemeOption('apola-header-side-color-scheme', 'apo-header-light', array(
	'overriden_by' => 'apola-page-header-side-color-scheme-individual',
	'depend_on' => array( 'key' => 'apola-page-header-state-individual', 'value' => '0' )
));
$apola_header_position = $Apola->getThemeOption('apola-header-side-position', 'apo-header-vertical-left', array(
	'overriden_by' => 'apola-page-header-side-position-individual',
	'depend_on' => array( 'key' => 'apola-page-header-state-individual', 'value' => '0' )
));
$apola_header_logo_state = $Apola->getThemeOption('apola-header-side-show-logo', '1', array(
	'overriden_by' => 'apola-page-header-side-show-logo-individual',
	'depend_on' => array( 'key' => 'apola-page-header-state-individual', 'value' => '0' )
));
$apola_header_social_icons_state = $Apola->getThemeOption('apola-header-side-show-social-icons', '1', array(
	'overriden_by' => 'apola-page-header-side-show-social-icons-individual',
	'depend_on' => array( 'key' => 'apola-page-header-state-individual', 'value' => '0' )
));
$apola_header_title_state = $Apola->getThemeOption('apola-header-side-show-site-title', '1', array(
	'overriden_by' => 'apola-page-header-side-show-site-title-individual',
	'depend_on' => array( 'key' => 'apola-page-header-state-individual', 'value' => '0' )
));
$apola_header_search_state = $Apola->getThemeOption('apola-header-side-show-search', '1', array(
	'overriden_by' => 'apola-page-header-side-show-search-individual',
	'depend_on' => array( 'key' => 'apola-page-header-state-individual', 'value' => '0' )
));

array_push($apola_header_classes, $apola_header_color_scheme);
array_push($apola_hidden_column_classes, (($apola_header_color_scheme == 'apo-header-dark') ? 'apo-hidden-column-dark' : 'apo-hidden-column-light'));
?>
<!-- - - - - - - - - - - - - - Hidden Aside Column - - - - - - - - - - - - - - - - -->
<aside id="apo-hidden-column" class="apo-hidden-column <?php echo esc_attr($ApolaHelper->getSanitizedHtmlClasses($apola_hidden_column_classes)); ?>">
    <div class="apo-hidden-column-container">
        <header class="apo-hidden-column-header">
            <div class="apo-hidden-column-col">
                <div class="apo-grid apo-cols-2">
					<?php if($apola_header_logo_state) : ?>
	                    <div class="apo-grid-col">
	                        <?php apola_logo('vertical', ($apola_header_color_scheme == 'apo-header-dark' ? 'light' : 'dark')); ?>
	                    </div>
					<?php endif; ?>
					<?php if($apola_header_social_icons_state) : ?>
	                    <div class="apo-grid-col">
	                        <!-- - - - - - - - - - - - - - Social Networks - - - - - - - - - - - - - - - - -->
	                        <?php apola_social_links(); ?>
	                        <!-- - - - - - - - - - - - - - End of Social Networks - - - - - - - - - - - - - - - - -->
	                    </div>
					<?php endif; ?>
                </div>
            </div>
        </header>
        <div class="apo-hidden-column-content">
            <div class="apo-hidden-column-col">
                <!-- - - - - - - - - - - - - - Primary Navigation - - - - - - - - - - - - - - - - -->
                <?php apola_navigation('primary'); ?>
                <!-- - - - - - - - - - - - - - End of Primary Navigation - - - - - - - - - - - - - - - - -->
            </div>
        </div>
        <footer class="apo-hidden-column-footer">
            <div class="apo-hidden-column-col">
                <div class="apo-hidden-column-actions">
					<?php if($apola_header_search_state) : ?>
	                    <div class="apo-hidden-column-action">
							<?php get_search_form(); ?>
	                    </div>
					<?php endif; ?>
                    <div class="apo-hidden-column-action">
                        <button class="apo-close-btn apo-hidden-column-closing">
                            <i class="icon icon-cross"></i>
							<?php esc_html_e('Close', 'apola'); ?>
                        </button>
                    </div>
                </div>
            </div>
        </footer>
    </div>
</aside>
<!-- - - - - - - - - - - - - - End of Hidden Aside Column - - - - - - - - - - - - - - - - -->

<!-- - - - - - - - - - - - - - Site Header - - - - - - - - - - - - - - - - -->
<header id="apo-header" class="apo-header apo-header-vertical <?php echo esc_attr($ApolaHelper->getSanitizedHtmlClasses($apola_header_classes)); ?>">
	<div class="apo-header-section">
		<div class="apo-header-component-first">
			<div class="apo-header-items">
				<?php if($apola_header_logo_state) : ?>
					<div class="apo-header-item">
						<?php apola_logo('vertical', ($apola_header_color_scheme == 'apo-header-dark' ? 'light' : 'dark')); ?>
					</div>
				<?php endif; ?>

				<?php if($apola_header_social_icons_state) : ?>
					<div class="apo-header-item">
						<!-- - - - - - - - - - - - - - Social Networks - - - - - - - - - - - - - - - - -->
						<?php apola_social_links(); ?>
						<!-- - - - - - - - - - - - - - End of Social Networks - - - - - - - - - - - - - - - - -->
					</div>
				<?php endif; ?>
			</div>
		</div>
		<div class="apo-header-component-middle">
			<div class="apo-header-items">
				<?php if($apola_header_title_state) : ?>
					<div class="apo-header-item">
						<h1 class="apo-page-title"><?php echo esc_html(get_bloginfo('name')); ?></h1>
					</div>
				<?php endif; ?>
			</div>
		</div>
		<div class="apo-header-component-last">
			<div class="apo-header-items">
				<?php if($apola_header_search_state) : ?>
					<div class="apo-header-item">
						<!-- - - - - - - - - - - - - - Search Button - - - - - - - - - - - - - - - - -->
						<button type="button" class="apo-header-button" data-arctic-modal="#modal-search">
							<i class="icon icon-magnifier"></i>
						</button>
						<!-- - - - - - - - - - - - - - End of Search Button - - - - - - - - - - - - - - - - -->
					</div>
				<?php endif; ?>

				<div class="apo-header-item">
					<!-- - - - - - - - - - - - - - Navigation Button - - - - - - - - - - - - - - - - -->
					<div role="button" class="apo-header-button apo-hidden-column-invoker apo-d-xs-none hamburger hamburger--emphatic">
						<span class="hamburger-box">
							<span class="hamburger-inner"></span>
						</span>
					</div>
					<!-- - - - - - - - - - - - - - End of Navigation Button - - - - - - - - - - - - - - - - -->

					<!-- - - - - - - - - - - - - - Mobile Navigation Button - - - - - - - - - - - - - - - - -->
					<div role="button" data-arctic-modal="#modal-nav" class="apo-header-button hamburger apo-d-none apo-d-xs-inline-block hamburger--emphatic apo-hamburger-clickable">
						<span class="hamburger-box">
							<span class="hamburger-inner"></span>
						</span>
					</div>
					<!-- - - - - - - - - - - - - - End of Mobile Navigation Button - - - - - - - - - - - - - - - - -->
					<!-- - - - - - - - - - - - - - Search Form Popup - - - - - - - - - - - - - - - - -->
					<div class="apo-d-none">
						<div id="modal-search" class="apo-modal apo-modal-search">
							<header class="apo-modal-search-header">
						        <h2 class="apo-modal-search-title"><?php esc_html_e('Find everything', 'apola'); ?></h2>
						    </header>

						    <div class="apo-modal-search-body">
						        <?php get_search_form(); ?>
						    </div>

						    <div class="arctic-modal-close-container">
						        <button type="button" class="apo-close-btn arcticmodal-close">
						            <i class="icon icon-cross"></i> <?php esc_html_e('Close', 'apola'); ?>
						        </button>
						    </div>

							<div class="arctic-modal-close-container">
								<button type="button" class="apo-close-btn arcticmodal-close"><i class="icon icon-cross"></i> <?php esc_html_e('Close', 'apola'); ?></button>
							</div>
						</div>
					</div>
					<!-- - - - - - - - - - - - - - End of Search Form Popup - - - - - - - - - - - - - - - - -->

					<!-- - - - - - - - - - - - - - Navigation Popup - - - - - - - - - - - - - - - - -->
					<div class="apo-d-none">
						<div id="modal-nav" class="apo-modal apo-modal-fullscreen-nav">
							<div class="container">
								<div class="apo-section">
									<?php apola_navigation('primary', array(
										'container_class' => 'apo-navigation-vertical-container',
										'menu_class' => 'apo-navigation-vertical'
									)); ?>

									<?php get_search_form(); ?>
								</div>
							</div>

							<div class="arctic-modal-close-container">
								<button type="button" class="apo-close-btn arcticmodal-close"><i class="icon icon-cross"></i> <?php esc_html_e('Close', 'apola'); ?></button>
							</div>
						</div>
					</div>
					<!-- - - - - - - - - - - - - - End of Navigation Popup - - - - - - - - - - - - - - - - -->
				</div>
			</div>
		</div>
	</div>
</header>
<!-- - - - - - - - - - - - - - End of Site Header - - - - - - - - - - - - - - - - -->
