<?php
/**
* The template file that describes horizontal header markup
*
* @package WordPress
* @subpackage Apola
* @since Apola 1.0
*/

// Prevent the direct loading of the file
if ( ! defined( 'ABSPATH' ) ) {
	die( esc_html__('You cannot access this file directly', 'apola') );
}

if(!class_exists('ApolaGalleryRepository') || !class_exists('ApolaPostRepository')) return;

global $Apola, $ApolaPostLiker;
$ApolaHelper = $Apola->helper();
$apola_header_classes = array();

$apola_header_color_scheme = $Apola->getThemeOption('apola-header-top-color-scheme', 'apo-header-light', array(
	'overriden_by' => 'apola-page-header-top-color-scheme-slideshow-individual',
	'depend_on' => array( 'key' => 'apola-page-header-state-individual', 'value' => '0' )
));
$apola_header_thumbs_state = $Apola->getThemeOption('apola-page-header-portfolio-slideshow-show-thumbs', 1);
$apola_header_likes_state = $Apola->getThemeOption('apola-page-header-portfolio-slideshow-show-likes', 1);
$apola_header_fullscreen_state = $Apola->getThemeOption('apola-page-header-portfolio-slideshow-show-fullscreen', 1);


// Getting the page content options
$apola_content_source = $Apola->getThemeOption('apola-page-type-portfolio-gallery-content-source', 'apola-portfolio');
$apola_is_gallery = $apola_content_source == 'apola-gallery';
$ApolaPostsRepository = $apola_is_gallery ? new ApolaGalleryRepository() : new ApolaPostRepository('apola-portfolio');
$ApolaPostLiker = new ApolaPostLiker($ApolaPostsRepository);

// Getting the query arguments
$apola_query_paged = get_query_var('paged') ? get_query_var('paged') : 1;
$apola_query_limit = $Apola->getThemeOption('apola-page-type-portfolio-gallery-items-per-page', 16);
$apola_query_orderby = $Apola->getThemeOption('apola-page-type-portfolio-gallery-order-by', 'date');
$apola_query_order = $Apola->getThemeOption('apola-page-type-portfolio-gallery-sort-order', 'desc');
$apola_query_offset = $Apola->getThemeOption('apola-page-type-portfolio-gallery-portfolio-offset', 0);
$apola_query_exclude = $Apola->getThemeOption(sprintf('apola-page-type-portfolio-gallery-%s-out', ($apola_is_gallery ? 'galleries' : 'portfolio')), array());
$apola_query_include = $Apola->getThemeOption(sprintf('apola-page-type-portfolio-gallery-%s-in', ($apola_is_gallery ? 'galleries' : 'portfolio')), array());
$apola_query_cats = $Apola->getThemeOption(sprintf('apola-page-type-portfolio-gallery-%s-categories', ($apola_is_gallery ? 'galleries' : 'portfolio')), array());

$apola_posts = $ApolaPostsRepository->fromCategories($apola_query_cats, ($apola_is_gallery ? 'apola-gallery-categories' : 'apola-portfolio-categories'))
									->in($apola_query_include)
									->out($apola_query_exclude)
									->orderBy($apola_query_orderby)
									->order($apola_query_order)
									->offset(($apola_query_paged - 1) * intval($apola_query_limit))
									->limit($apola_query_limit)
									->get();

array_push($apola_header_classes, $apola_header_color_scheme);

?>
<!-- - - - - - - - - - - - - - Site Header - - - - - - - - - - - - - - - - -->
<header id="apo-header" class="apo-header apo-header-bottom <?php echo esc_attr($ApolaHelper->getSanitizedHtmlClasses($apola_header_classes)); ?>">
    <div class="apo-header-section">
        <div class="apo-header-component-first">
            <div class="apo-header-items">
                <div class="apo-header-item">
                    <!-- - - - - - - - - - - - - - Navigation Button - - - - - - - - - - - - - -->
                    <div type="button" data-arctic-modal="#modal-nav" class="apo-header-button hamburger hamburger--emphatic apo-hamburger-clickable">
                        <span class="hamburger-box">
                            <span class="hamburger-inner"></span>
                        </span>
                    </div>
                    <!-- - - - - - - - - - - - - - End of Navigation Button - - - - - - - - - - - - - -->

                    <!-- - - - - - - - - - - - - - Navigation Popup - - - - - - - - - - - - - - - - -->
                    <div class="apo-d-none">
                        <div id="modal-nav" class="apo-modal apo-modal-fullscreen-nav">
                            <div class="container">
                                <div class="apo-section">
                                    <?php apola_navigation('primary', array(
										'container_class' => 'apo-navigation-vertical-container',
										'menu_class' => 'apo-navigation-vertical'
                                    )); ?>

                                    <?php get_search_form(); ?>
                                </div>
                            </div>

                            <div class="arctic-modal-close-container">
                                <button type="button" class="apo-close-btn arcticmodal-close"><i class="icon icon-cross"></i> <?php esc_html_e('Close', 'apola'); ?></button>
                            </div>
                        </div>
                    </div>
                    <!-- - - - - - - - - - - - - - End of Navigation Popup - - - - - - - - - - - - - - - - -->
                </div>

                <div class="apo-header-item">
                    <?php apola_logo('horizontal', ($apola_header_color_scheme == 'apo-header-dark' ? 'light' : 'dark')); ?>
                </div>
            </div>
        </div>

        <?php if($apola_header_thumbs_state == 1 && is_array($apola_posts) && count($apola_posts)) : ?>
	        <div class="apo-header-component-middle">
	            <div class="apo-header-items">
                    <div class="apo-header-item">
                        <!-- - - - - - - - - - - - - - Slide Thumbnails - - - - - - - - - - - - - -->
                        <nav class="apo-slider-thumbs apo-slider-thumbs-hr swiper-container">
                            <button class="swiper-button-prev">
                                <i class="icon icon-chevron-left"></i>
                            </button>

                            <div class="swiper-wrapper">
								<?php foreach($apola_posts as $post) :
									if($post instanceof WP_Post) setup_postdata($post);
								?>
                                    <div class="swiper-slide">
										<?php if($post instanceof WP_Post) : ?>
                                        	<div class="apo-slider-thumb"
												 data-bg-img-src="<?php echo esc_attr(get_the_post_thumbnail_url(get_the_ID(), array(150, 150))); ?>"></div>
										<?php elseif(is_array($post) && isset($post['attach_id'])) : ?>
											<div class="apo-slider-thumb"
												 data-bg-img-src="<?php echo esc_attr(wp_get_attachment_image_url($post['attach_id'], array(150, 150))); ?>"></div>
										<?php endif; ?>
                                    </div>
                                <?php endforeach; wp_reset_postdata(); ?>
                            </div>

                            <button class="swiper-button-next">
                                <i class="icon icon-chevron-right"></i>
                            </button>
                        </nav>
                        <!-- - - - - - - - - - - - - - End of Slider Thumbnails - - - - - - - - - - - - - -->
                    </div>
	            </div>
	        </div>
		<?php endif; ?>

        <div class="apo-header-component-last">
			<div class="apo-header-items">
                <?php if(is_array($apola_posts) && count($apola_posts)) :
					$apola_first_post = $apola_posts[0];
					$apola_first_item_ajax_data = array(
						'post_type' => $apola_is_gallery ? 'apola-galleries' : 'apola-portfolio'
					);

					if($apola_first_post instanceof WP_Post) {
						$apola_first_item_ajax_data['item_id'] = $apola_first_post->ID;
					}
					elseif(is_array($apola_first_post) && isset($apola_first_post['attach_id'])) {
						$apola_first_item_ajax_data['item_id'] =  $apola_first_post['attach_id'];

						if(isset($apola_first_post['parent_gallery_id'])) {
							$apola_first_item_ajax_data['parent_gallery_id'] = $apola_first_post['parent_gallery_id'];
						}
					}

					if(isset($apola_first_item_ajax_data['item_id']) && is_numeric($apola_first_item_ajax_data['item_id'])) {
						$apola_first_item_ajax_data['likes'] = $ApolaPostLiker->getLikesCount($apola_first_item_ajax_data['item_id']);
					}
                ?>
					<?php if($apola_header_likes_state == 1) : ?>
	                    <div class="apo-header-item">
	                        <!-- - - - - - - - - - - - - - Like Button - - - - - - - - - - - - - -->
	                        <button class="apo-hover-btn apo-item-likes-btn"
	                                type="button"
	                                data-item-likes-data="<?php echo esc_attr(wp_json_encode($apola_first_item_ajax_data)); ?>">
	                            <span class="apo-hover-btn-tooltip apo-item-likes"><?php echo esc_html($apola_first_item_ajax_data['likes']); ?></span>
	                            <i class="icon icon-heart"></i>
	                        </button>
	                        <!-- - - - - - - - - - - - - - End of Like Button - - - - - - - - - - - - - -->
	                    </div>
					<?php endif; ?>

					<?php if($apola_header_fullscreen_state == 1) : ?>
	                    <div class="apo-header-item apo-fullscreen-control">
	                        <!-- - - - - - - - - - - - - - Full Screen Button - - - - - - - - - - - - - -->
	                        <button type="button" class="apo-hover-btn">
	                            <i class="icon icon-expand"></i>
	                        </button>
	                        <!-- - - - - - - - - - - - - - End of Full Screen Button - - - - - - - - - - - - - -->
	                    </div>
					<?php endif; ?>

                    <div class="apo-header-item">
                        <!-- - - - - - - - - - - - - - Info Button - - - - - - - - - - - - - -->
                        <button type="button"
                               class="apo-hover-btn apo-modal-info-invoker"
                               data-arctic-modal="true"
                               data-arctic-modal-type="ajax"
                               data-arctic-modal-ajax-action="show_item_info_modal"
                               data-arctic-modal-ajax-data="<?php echo esc_attr(wp_json_encode($apola_first_item_ajax_data)); ?>">
                           <i class="icon icon-menu-circle"></i>
                       </button>
                        <!-- - - - - - - - - - - - - - End of Info Button - - - - - - - - - - - - - -->
                    </div>
                <?php endif; ?>
			</div>
        </div>
    </div>
</header>
<!-- - - - - - - - - - - - - - End of Site Header - - - - - - - - - - - - - - - - -->
