<?php
/**
* The template file that describes horizontal header markup
*
* @package WordPress
* @subpackage Apola
* @since Apola 1.0
*/

// Prevent the direct loading of the file
if ( ! defined( 'ABSPATH' ) ) {
	die( esc_html__('You cannot access this file directly', 'apola') );
}

global $Apola;
$ApolaHelper = $Apola->helper();

$apola_header_color_scheme = $Apola->getThemeOption('apola-header-top-color-scheme', 'apo-header-light', array(
	'overriden_by' => 'apola-page-header-top-color-scheme-individual',
	'depend_on' => array( 'key' => 'apola-page-header-state-individual', 'value' => '0' )
));
$apola_header_is_sticky = $Apola->getThemeOption('apola-header-top-sticky', false, array(
	'overriden_by' => 'apola-page-header-top-sticky-individual',
	'depend_on' => array( 'key' => 'apola-page-header-state-individual', 'value' => '0' )
));
$apola_header_left_column_elements = $Apola->getThemeOption('apola-header-top-left-column-elements', 'apola-logo', array(
	'overriden_by' => 'apola-page-header-top-left-column-elements-individual',
	'depend_on' => array( 'key' => 'apola-page-header-state-individual', 'value' => '0' )
));
$apola_header_middle_column_elements = $Apola->getThemeOption('apola-header-top-middle-column-elements', 'apola-navigation', array(
	'overriden_by' => 'apola-page-header-top-middle-column-elements-individual',
	'depend_on' => array( 'key' => 'apola-page-header-state-individual', 'value' => '0' )
));
$apola_header_right_column_elements = $Apola->getThemeOption('apola-header-top-right-column-elements', 'apola-search-form', array(
	'overriden_by' => 'apola-page-header-top-right-column-elements-individual',
	'depend_on' => array( 'key' => 'apola-page-header-state-individual', 'value' => '0' )
));

$apola_header_classes = array();
array_push($apola_header_classes, $apola_header_color_scheme);

if($apola_header_color_scheme == 'apo-header-light') {
	array_push($apola_header_classes, 'apo-style-3');
}
?>
<!-- - - - - - - - - - - - - - Site Header - - - - - - - - - - - - - - - - -->
<header id="apo-header" class="apo-header <?php echo esc_attr($ApolaHelper->getSanitizedHtmlClasses($apola_header_classes)); ?>">
    <div class="apo-header-section <?php if($apola_header_is_sticky) echo sanitize_html_class('apo-sticky'); ?>">
		<?php if(count($apola_header_left_column_elements)) : ?>
	        <div class="apo-header-component-first">
	            <div class="apo-header-items">
	                <?php foreach($apola_header_left_column_elements as $element) : ?>
	                    <?php switch($element) {
	                            case 'apola-logo' : ?>
	                                <div class="apo-header-item">
	                                    <?php apola_logo('horizontal', (($apola_header_color_scheme == 'apo-header-dark' || $apola_header_color_scheme == 'apo-header-transparent-dark') ? 'light' : 'dark')); ?>
	                                </div>
	                            <?php break;
	                            case 'apola-search-form' : ?>
	                                <div class="apo-header-item apo-rounded-form">
	                                    <?php get_search_form(); ?>
	                                </div>
	                            <?php break;
	                            case 'apola-navigation' : ?>
	                                <div class="apo-header-item">
	                                    <?php apola_navigation('primary'); ?>
	                                </div>
	                            <?php break;
	                            case 'apola-nav-button' : ?>
	                                <div class="apo-header-item">
	                                    <!-- - - - - - - - - - - - - - Navigation Button - - - - - - - - - - - - - - - - -->
	                                    <button type="button" data-arctic-modal="#modal-nav" class="hamburger hamburger--emphatic apo-hamburger-clickable"><span class="hamburger-box"><span class="hamburger-inner"></span></span></button>
	                                    <!-- - - - - - - - - - - - - - End of Navigation Button - - - - - - - - - - - - - - - - -->
	                                </div>
	                            <?php break;
	                            case 'apola-social-links' : ?>
	                                <div class="apo-header-item">
	                                    <?php apola_social_links(); ?>
	                                </div>
	                            <?php break;
	                        } ?>
	                <?php endforeach; ?>
	            </div>
	        </div>
		<?php endif; ?>

		<?php if(count($apola_header_middle_column_elements)) : ?>
	        <div class="apo-header-component-middle">
	            <div class="apo-header-items">
	                <?php foreach($apola_header_middle_column_elements as $element) : ?>
	                    <?php switch($element) {
	                            case 'apola-logo' : ?>
	                                <div class="apo-header-item">
	                                    <?php apola_logo('horizontal', (($apola_header_color_scheme == 'apo-header-dark' || $apola_header_color_scheme == 'apo-header-transparent-dark') ? 'light' : 'dark')); ?>
	                                </div>
	                            <?php break;
	                            case 'apola-search-form' : ?>
	                                <div class="apo-header-item apo-rounded-form">
	                                    <?php get_search_form(); ?>
	                                </div>
	                            <?php break;
	                            case 'apola-navigation' : ?>
	                                <div class="apo-header-item">
										<?php apola_navigation('primary'); ?>
									</div>
	                            <?php break;
	                            case 'apola-nav-button' : ?>
	                                <div class="apo-header-item">
	                                    <!-- - - - - - - - - - - - - - Navigation Button - - - - - - - - - - - - - - - - -->
	                                    <button type="button" data-arctic-modal="#modal-nav" class="hamburger hamburger--emphatic apo-hamburger-clickable"><span class="hamburger-box"><span class="hamburger-inner"></span></span></button>
	                                    <!-- - - - - - - - - - - - - - End of Navigation Button - - - - - - - - - - - - - - - - -->
	                                </div>
	                            <?php break;
	                            case 'apola-social-links' : ?>
	                                <div class="apo-header-item">
	                                    <?php apola_social_links(); ?>
	                                </div>
	                            <?php break;
	                        } ?>
	                <?php endforeach; ?>
	            </div>
	        </div>
		<?php endif; ?>

		<?php if(count($apola_header_right_column_elements)) : ?>
	        <div class="apo-header-component-last">
	            <div class="apo-header-items">
	                <?php foreach($apola_header_right_column_elements as $element) : ?>
	                    <?php switch($element) {
	                            case 'apola-logo' : ?>
	                                <div class="apo-header-item">
	                                    <?php apola_logo('horizontal', (($apola_header_color_scheme == 'apo-header-dark' || $apola_header_color_scheme == 'apo-header-transparent-dark') ? 'light' : 'dark')); ?>
	                                </div>
	                            <?php break;
	                            case 'apola-search-form' : ?>
	                                <div class="apo-header-item apo-rounded-form">
	                                    <?php get_search_form(); ?>
	                                </div>
	                            <?php break;
	                            case 'apola-navigation' : ?>
	                                <div class="apo-header-item">
	                                    <?php apola_navigation('primary'); ?>
	                                </div>
	                            <?php break;
	                            case 'apola-nav-button' : ?>
	                                <div class="apo-header-item">
	                                    <!-- - - - - - - - - - - - - - Navigation Button - - - - - - - - - - - - - - - - -->
	                                    <button type="button" data-arctic-modal="#modal-nav" class="hamburger hamburger--emphatic apo-hamburger-clickable"><span class="hamburger-box"><span class="hamburger-inner"></span></span></button>
	                                    <!-- - - - - - - - - - - - - - End of Navigation Button - - - - - - - - - - - - - - - - -->
	                                </div>
	                            <?php break;
	                            case 'apola-social-links' : ?>
	                                <div class="apo-header-item">
	                                    <?php apola_social_links(); ?>
	                                </div>
	                            <?php break;
	                        } ?>
	                <?php endforeach; ?>
	            </div>
	        </div>
		<?php endif; ?>
    </div>
</header>
<!-- - - - - - - - - - - - - - End of Site Header - - - - - - - - - - - - - - - - -->

<?php if(in_array('apola-nav-button', $apola_header_left_column_elements) || in_array('apola-nav-button', $apola_header_middle_column_elements) || in_array('apola-nav-button', $apola_header_right_column_elements)) : ?>
	<!-- - - - - - - - - - - - - - Navigation Popup - - - - - - - - - - - - - - - - -->
	<div class="apo-d-none">
		<div id="modal-nav" class="apo-modal apo-modal-fullscreen-nav">
			<div class="container">
				<div class="apo-section">
					<?php apola_navigation('primary', array(
						'container_class' => 'apo-navigation-vertical-container',
						'menu_class' => 'apo-navigation-vertical'
					)); ?>

					<?php get_search_form(); ?>
				</div>
			</div>

			<div class="arctic-modal-close-container">
				<button type="button" class="apo-close-btn arcticmodal-close"><i class="icon icon-cross"></i> <?php esc_html_e('Close', 'apola'); ?></button>
			</div>
		</div>
	</div>
	<!-- - - - - - - - - - - - - - End of Navigation Popup - - - - - - - - - - - - - - - - -->
<?php endif; ?>
