<?php
/**
* The template file for displaying a blogroll page.
*
* @package WordPress
* @subpackage Apola
* @since Apola 1.0
*/

// Prevent the direct loading of the file
if ( ! defined( 'ABSPATH' ) ) {
	die( esc_html__('You cannot access this file directly', 'apola') );
}

if(!class_exists('ApolaPostRepository')) return;

global $Apola, $post;
$ApolaHelper = $Apola->helper();

$apola_single_page_layout = $Apola->getThemeOption('apola-page-layout', 'apo-no-sidebar', array(
	'overriden_by' => 'apola-page-type-blogroll-layout',
	'depend_on' => array( 'key' => 'apola-page-settings-inherit-individual', 'value' => 0 )
));

$apola_page_vertical_padding = $Apola->getThemeOption('apola-page-vertical-padding', array('padding-top' => 85, 'padding-bottom' => 85), array(
	'overriden_by' => 'post-archive-vertical-padding',
	'depend_on' => array( 'key' => 'apola-page-settings-inherit-individual', 'value' => 0 )
));

$apola_page_top_padding_individual = $Apola->getThemeOption('apola-page-top-padding-individual');
$apola_page_bottom_padding_individual = $Apola->getThemeOption('apola-page-bottom-padding-individual');

if(strlen($apola_page_top_padding_individual)) {
	$apola_page_vertical_padding['padding-top'] = intval($apola_page_top_padding_individual);
}
if(strlen($apola_page_bottom_padding_individual)) {
	$apola_page_vertical_padding['padding-bottom'] = intval($apola_page_bottom_padding_individual);
}

$apola_has_sidebar = in_array($apola_single_page_layout, array('apo-left-sidebar', 'apo-right-sidebar'));
$apola_page_title = $Apola->getThemeOption('apola-page-title', 'apo-style-1', array(
	'overriden_by' => 'apola-page-title-individual',
	'depend_on' => array( 'key' => 'apola-page-settings-inherit-individual', 'value' => 0 )
));
$apola_page_title_position = $Apola->getThemeOption('apola-page-title-position', 'apo-align-none', array(
	'overriden_by' => 'apola-page-title-position-individual',
	'depend_on' => array( 'key' => 'apola-page-settings-inherit-individual', 'value' => 0 )
));
$apola_page_breadcrumbs = $Apola->getThemeOption('apola-page-breadcrumbs', 'apola-page-breadcrumbs-show', array(
	'overriden_by' => 'apola-page-breadcrumbs-individual',
	'depend_on' => array( 'key' => 'apola-page-settings-inherit-individual', 'value' => 0 )
));
$apola_layout_classes = $ApolaHelper->getMainLayoutClasses($apola_single_page_layout);
$apola_blog_display_style = $Apola->getThemeOption('blog-default-style', 'apo-style-3', array(
	'overriden_by' => 'apola-page-type-blogroll-style',
	'depend_on' => array( 'key' => 'apola-page-type-individual', 'value' => 'apola-blogroll' )
));
$apola_blog_isotope_layout = $Apola->getThemeOption('blog-isotope-layout-type', 'grid', array(
	'overriden_by' => 'apola-page-type-blogroll-isotope-layout-type',
	'depend_on' => array( 'key' => 'apola-page-type-individual', 'value' => 'apola-blogroll' )
));
$apola_blog_columns = $Apola->getThemeOption('blog-default-columns', 'apo-cols-2', array(
	'overriden_by' => 'apola-page-type-blogroll-columns',
	'depend_on' => array( 'key' => 'apola-page-type-individual', 'value' => 'apola-blogroll' )
));

$apola_blog_filter_state = $Apola->getThemeOption('apola-page-type-blogroll-filter', '1');
$apola_blog_filter_all_tab = $Apola->getThemeOption('apola-page-type-blogroll-filter-all-tab', esc_html__('All', 'apola'));
$apola_blog_items_slide_effect = $Apola->getThemeOption('apola-page-type-blogroll-isotope-slide-effect', 1);

$apola_blog_data_items_per_page = $Apola->getThemeOption('apola-page-type-blogroll-data-items-per-page', get_option('posts_per_page'));
$apola_blog_data_order_by = $Apola->getThemeOption('apola-page-type-blogroll-data-order-by', 'date');
$apola_blog_data_sort_order = $Apola->getThemeOption('apola-page-type-blogroll-data-sort-order', 'DESC');
$apola_blog_data_categories = $Apola->getThemeOption('apola-page-type-blogroll-data-categories', array());
$apola_blog_data_tags = $Apola->getThemeOption('apola-page-type-blogroll-data-tags', array());
$apola_blog_data_posts_in = $Apola->getThemeOption('apola-page-type-blogroll-data-in', array());
$apola_blog_data_posts_out = $Apola->getThemeOption('apola-page-type-blogroll-data-out', array());

set_query_var('apola-blog-post-style', $apola_blog_display_style);

$apola_blog_container_classes = array($apola_blog_display_style, $apola_blog_columns);

if(in_array($apola_blog_display_style, array('apo-style-1', 'apo-style-2', 'apo-style-3')) && $apola_blog_items_slide_effect == 1) {
	array_push($apola_blog_container_classes, 'apo-isotope-has-slide-effect');
}

$apola_section_classes = array();
$apola_paged = get_query_var('paged') ? get_query_var('paged') : 1;
$ApolaPostsRepository = new ApolaPostRepository('post');

if($apola_blog_filter_state == '1') {
	$apola_page_title_position = 'apo-auto-align';
}
array_push($apola_section_classes, ($apola_has_sidebar ? 'apo-has-sidebar' : 'apo-has-not-sidebar'));

if($apola_single_page_layout == 'apo-full-width') {
	array_push($apola_section_classes, 'apo-full-width');
}

$apola_entries = $ApolaPostsRepository->fromCategories($apola_blog_data_categories, 'category')
									  ->fromCategories($apola_blog_data_tags, 'post_tag')
									  ->in($apola_blog_data_posts_in)
									  ->out($apola_blog_data_posts_out)
									  ->orderBy($apola_blog_data_order_by)
									  ->order($apola_blog_data_sort_order)
									  ->offset(($apola_paged - 1) * intval($apola_blog_data_items_per_page))
									  ->limit($apola_blog_data_items_per_page)
									  ->get();

get_header(); ?>

<?php if($apola_page_title != 'apo-hidden' || $apola_blog_filter_state != 0) : ?>
	<!-- - - - - - - - - - - - - - Page Header - - - - - - - - - - - - - - - - -->
	<div class="apo-page-header <?php echo sanitize_html_class($apola_page_title); ?>">
        <?php if($apola_page_title != 'apo-hidden') : ?>
    	    <div class="apo-page-header-column <?php echo sanitize_html_class($apola_page_title_position); ?>">
    	        <h1 class="apo-page-title"><?php the_title(); ?></h1>
    			<?php if($apola_page_breadcrumbs == 'apola-page-breadcrumbs-show' ) : ?>
    				<!-- - - - - - - - - - - - - - Breadcrumbs - - - - - - - - - - - - - - - - -->
    				<?php apola_breadcrumbs(); ?>
    				<!-- - - - - - - - - - - - - - End of Breadcrumbs - - - - - - - - - - - - - - - - -->
    			<?php endif; ?>
    	    </div>
        <?php endif; ?>

        <?php if($apola_blog_filter_state == '1') : ?>
            <div class="apo-page-header-column">
                <!-- - - - - - - - - - - - - - Isotope Filter - - - - - - - - - - - - - - - - -->
                <?php apola_display_filter($apola_entries, 'apola-blog-filter', esc_html($apola_blog_filter_all_tab)); ?>
                <!-- - - - - - - - - - - - - - End of Isotope Filter - - - - - - - - - - - - - - - - -->
            </div>
        <?php endif; ?>
	</div>
	<!-- - - - - - - - - - - - - - End of Page Header - - - - - - - - - - - - - - - - -->
<?php endif; ?>

<div class="apo-section <?php echo esc_attr($ApolaHelper->getSanitizedHtmlClasses($apola_section_classes)); ?>" style="padding-top: <?php echo esc_attr($apola_page_vertical_padding['padding-top']); ?>px; padding-bottom: <?php echo esc_attr($apola_page_vertical_padding['padding-bottom']); ?>px;">
	<div class="row">
		<!-- - - - - - - - - - - - - - Main Content Column - - - - - - - - - - - - - - - - -->
		<main class="<?php echo esc_attr($ApolaHelper->getSanitizedHtmlClasses($apola_layout_classes['main_column'])); ?>">
			<?php if(count($apola_entries)) : ?>
                <div class="apo-section">
			        <!-- - - - - - - - - - - - - - Isotope Container - - - - - - - - - - - - - - - - -->
			        <div class="apo-isotope apo-entries-container <?php echo esc_attr($ApolaHelper->getSanitizedHtmlClasses($apola_blog_container_classes)); ?>"
						data-items-per-page="<?php echo esc_attr( get_option('posts_per_page') ); ?>"
						data-isotope-layout="<?php echo esc_attr($apola_blog_isotope_layout); ?>"
                        data-isotope-filter="#apola-blog-filter">
			            <?php
							$apola_loop_counter = 0;
                            foreach($apola_entries as $post) {
                                setup_postdata($post);
								if($apola_blog_isotope_layout == 'masonry') set_query_var('apola-item-thumb-size', sprintf('apola-blog-thumb-%s', ($apola_loop_counter % 2 == 0) ? 'vertical' : 'horizontal'));
                                get_template_part( 'template-parts/post/blog', 'post' );
								$apola_loop_counter++;
                            }

                            wp_reset_postdata();
			            ?>

						<div class="grid-sizer"></div>
			        </div>
			        <!-- - - - - - - - - - - - - - End of Isotope Container - - - - - - - - - - - - - - - - -->
			    </div>

                <!-- - - - - - - - - - - - - - Page Controls - - - - - - - - - - - - - - - - -->
                <div class="apo-page-controls">
                    <?php apola_pagination(array(
                        'total'   => ceil( count($ApolaPostsRepository) / $apola_blog_data_items_per_page ),
                        'current' => $apola_paged
                    )); ?>
				</div>
                <!-- - - - - - - - - - - - - - End of Page Controls - - - - - - - - - - - - - - - - -->
			<?php else : ?>
				<div class="apo-section">
					<?php get_template_part('template-parts/content', 'none'); ?>
	            </div>
			<?php endif; ?>
			<?php if(comments_open()) : ?>
				<hr/>
				<?php comments_template(); ?>
			<?php endif; ?>
		</main>
		<!-- - - - - - - - - - - - - - End of Main Content Column - - - - - - - - - - - - - - - - -->

		<?php if($apola_has_sidebar) : ?>
			<!-- - - - - - - - - - - - - - Sidebar - - - - - - - - - - - - - - - - -->
			<aside class="apo-sidebar <?php echo esc_attr($ApolaHelper->getSanitizedHtmlClasses($apola_layout_classes['side_column'])); ?>" id="apo-sidebar">
				<?php get_sidebar(); ?>
			</aside>
			<!-- - - - - - - - - - - - - - End of Sidebar - - - - - - - - - - - - - - - - -->
		<?php endif; ?>
	</div>
</div>

<?php get_footer(); ?>
