<?php
/**
* The template file for displaying a single page with default page type.
*
* @package WordPress
* @subpackage Apola
* @since Apola 1.0
*/

// Prevent the direct loading of the file
if ( ! defined( 'ABSPATH' ) ) {
	die( esc_html__('You cannot access this file directly', 'apola') );
}

global $Apola;
$ApolaHelper = $Apola->helper();

$apola_single_page_layout = $Apola->getThemeOption('apola-page-layout', 'apo-no-sidebar', array(
	'overriden_by' => 'apola-page-layout-individual',
	'depend_on' => array( 'key' => 'apola-page-settings-inherit-individual', 'value' => '0' )
));

$apola_page_vertical_padding = $Apola->getThemeOption('apola-page-vertical-padding', array('padding-top' => 85, 'padding-bottom' => 85));
$apola_page_top_padding_individual = $Apola->getThemeOption('apola-page-top-padding-individual');
$apola_page_bottom_padding_individual = $Apola->getThemeOption('apola-page-bottom-padding-individual');

if(strlen($apola_page_top_padding_individual)) {
	$apola_page_vertical_padding['padding-top'] = intval($apola_page_top_padding_individual);
}
if(strlen($apola_page_bottom_padding_individual)) {
	$apola_page_vertical_padding['padding-bottom'] = intval($apola_page_bottom_padding_individual);
}

$apola_page_title = $Apola->getThemeOption('apola-page-title', 'apo-style-1', array(
	'overriden_by' => 'apola-page-title-individual',
	'depend_on' => array( 'key' => 'apola-page-settings-inherit-individual', 'value' => 0 )
));
$apola_page_title_position = $Apola->getThemeOption('apola-page-title-position', 'apo-align-center', array(
	'overriden_by' => 'apola-page-title-position-individual',
	'depend_on' => array( 'key' => 'apola-page-settings-inherit-individual', 'value' => 0 )
));
$apola_page_breadcrumbs = $Apola->getThemeOption('apola-page-breadcrumbs', 'apola-page-breadcrumbs-show', array(
	'overriden_by' => 'apola-page-breadcrumbs-individual',
	'depend_on' => array( 'key' => 'apola-page-settings-inherit-individual', 'value' => 0 )
));

$apola_section_classes = array();
$apola_has_sidebar = in_array($apola_single_page_layout, array('apo-left-sidebar', 'apo-right-sidebar'));
$apola_layout_classes = $ApolaHelper->getMainLayoutClasses($apola_single_page_layout);

array_push($apola_section_classes, ($apola_has_sidebar ? 'apo-has-sidebar' : 'apo-has-not-sidebar'));

get_header(); ?>

<?php if($apola_page_title != 'apo-hidden') : ?>
	<!-- - - - - - - - - - - - - - Page Header - - - - - - - - - - - - - - - - -->
	<div class="apo-page-header <?php echo sanitize_html_class($apola_page_title); ?>">
	    <div class="apo-page-header-column <?php echo sanitize_html_class($apola_page_title_position); ?>">
	        <h1 class="apo-page-title"><?php the_title(); ?></h1>
			<?php if($apola_page_breadcrumbs == 'apola-page-breadcrumbs-show') : ?>
				<!-- - - - - - - - - - - - - - Breadcrumbs - - - - - - - - - - - - - - - - -->
				<?php apola_breadcrumbs(); ?>
				<!-- - - - - - - - - - - - - - End of Breadcrumbs - - - - - - - - - - - - - - - - -->
			<?php endif; ?>
	    </div>
	</div>
	<!-- - - - - - - - - - - - - - End of Page Header - - - - - - - - - - - - - - - - -->
<?php endif; ?>

<div class="apo-section <?php echo esc_attr($ApolaHelper->getSanitizedHtmlClasses($apola_section_classes)); ?>" style="padding-top: <?php echo esc_attr($apola_page_vertical_padding['padding-top']); ?>px; padding-bottom: <?php echo esc_attr($apola_page_vertical_padding['padding-bottom']); ?>px;">
	<div class="row">
		<!-- - - - - - - - - - - - - - Main Content Column - - - - - - - - - - - - - - - - -->
		<main class="<?php echo esc_attr($ApolaHelper->getSanitizedHtmlClasses($apola_layout_classes['main_column'])); ?>">
			<?php if(have_posts()) : ?>
		        <?php while( have_posts() ) :
                    the_post(); ?>
                    <div class="apo-page-content">
						<?php the_content(); ?>
					</div>
					<?php wp_link_pages( array(
						'before' => '<div class="apo-page-links"><span class="apo-page-links-title">' . esc_html__( 'Pages:', 'apola' ) . '</span>',
						'after' => '</div>',
						'link_before' => '<span>',
						'link_after' => '</span>'
					) ); ?>
            	<?php endwhile; ?>
			<?php else : ?>
				<?php get_template_part('template-parts/content', 'none'); ?>
			<?php endif; ?>
			<?php if(comments_open()) : ?>
				<hr/>
				<?php comments_template(); ?>
			<?php endif; ?>
		</main>
		<!-- - - - - - - - - - - - - - End of Main Content Column - - - - - - - - - - - - - - - - -->

		<?php if($apola_has_sidebar) : ?>
			<!-- - - - - - - - - - - - - - Sidebar - - - - - - - - - - - - - - - - -->
			<aside class="apo-sidebar <?php echo esc_attr($ApolaHelper->getSanitizedHtmlClasses($apola_layout_classes['side_column'])); ?>" id="apo-sidebar">
				<?php get_sidebar(); ?>
			</aside>
			<!-- - - - - - - - - - - - - - End of Sidebar - - - - - - - - - - - - - - - - -->
		<?php endif; ?>
	</div>
</div>

<?php get_footer(); ?>
