<?php
/**
* The template file for displaying a single page with 'fullpage' page type.
*
* @package WordPress
* @subpackage Apola
* @since Apola 1.0
*/

// Prevent the direct loading of the file
if ( ! defined( 'ABSPATH' ) ) {
	die( esc_html__('You cannot access this file directly', 'apola') );
}

global $Apola;
$Apola->setThemeOption('apola-footer-style', 'apola-none');

$apola_scroll_easing = $Apola->getThemeOption('apola-page-type-fullpage-easing', 'cubic-bezier(0.23, 1, 0.32, 1)');
$apola_scroll_speed = $Apola->getThemeOption('apola-page-type-fullpage-speed', 1500);

$apola_controls_slide_numbers = $Apola->getThemeOption('apola-page-type-fullpage-slide-numbers-state', 1);
$apola_controls_navigation = $Apola->getThemeOption('apola-page-type-fullpage-navigation-state', 1);
$apola_controls_languages = $Apola->getThemeOption('apola-page-type-fullpage-languages-state', 1);

$apola_controls_navigation_section = $Apola->getThemeOption('apola-page-type-fullpage-navigation-sections', array());
$apola_navigation_anchors = array();

get_header();
?>
<div class="apo-section apo-without-vertical-padding">
	<?php if(have_posts()) : ?>
		<?php while(have_posts()) : ?>
			<?php if($apola_controls_slide_numbers == 1 || $apola_controls_navigation == 1 || $apola_controls_languages == 1) : ?>
				<!-- - - - - - - - - - - - - - Controls Sidebar - - - - - - - - - - - - - -->
				<aside class="apo-full-page-controls">
					<header class="apo-full-page-controls-header">
						<?php if($apola_controls_slide_numbers == 1) : ?>
							<div class="apo-full-page-controls-item">
								<div class="apo-fp-slide-numbers"></div>
							</div>
						<?php endif; ?>
					</header>

					<div class="apo-full-page-controls-content">
						<?php if($apola_controls_navigation == 1) : ?>
							<div class="apo-full-page-controls-item">
								<?php if(is_array($apola_controls_navigation_section) && count($apola_controls_navigation_section)) : ?>
									<ul id="apo-fp-menu" class="apo-fp-menu">
										<?php foreach($apola_controls_navigation_section as $index => $section) :
											$apola_section_anchor = strtolower(preg_replace('/\s/', '-', $section));
											array_push($apola_navigation_anchors, sprintf('"%s"', $apola_section_anchor));
										?>
											<li data-menuanchor="<?php echo esc_attr($apola_section_anchor); ?>" <?php if($index == 0) : ?> class="active"<?php endif; ?>>
												<a href="#<?php echo esc_attr($apola_section_anchor); ?>"><span><?php echo esc_html($section); ?></span></a>
											</li>
										<?php endforeach; ?>
									</ul>
								<?php endif; ?>
							</div>
						<?php endif; ?>
					</div>

					<footer class="apo-full-page-controls-footer">
						<?php if($apola_controls_languages == 1) : ?>
							<div class="apo-full-page-controls-item">
								<?php apola_language_switcher(); ?>
							</div>
						<?php endif; ?>
					</footer>
				</aside>
				<!-- - - - - - - - - - - - - - End of Controls Sidebar - - - - - - - - - - - - - -->
			<?php endif; ?>
    		<!-- - - - - - - - - - - - - - Content Column - - - - - - - - - - - - - - - - -->
	    	<div id="apo-full-page" class="apo-full-page-container apo-page-content"
				 data-navigation="false"
				 data-menu="#apo-fp-menu"
				 data-anchors="[<?php echo esc_attr(implode(', ', $apola_navigation_anchors)); ?>]"
				 data-scrolling-speed="<?php echo esc_attr($apola_scroll_speed); ?>"
				 data-easingcss3="<?php echo esc_attr($apola_scroll_easing); ?>"
				 data-destroy-on-mobile="true"
				 data-show-scrolldown-label="false">
				<?php the_post(); the_content(); ?>
			</div>
			<!-- - - - - - - - - - - - - - End of Content Column - - - - - - - - - - - - - -->
		<?php endwhile; ?>
	<?php else : ?>
		<div class="apo-section-no-content">
			<?php get_template_part('content', 'none'); ?>
		</div>
	<?php endif; ?>
</div>

<?php get_footer(); ?>
