<?php
/**
* The template file for displaying a portfolio/gallery page with "full-page" style.
*
* @package WordPress
* @subpackage Apola
* @since Apola 1.0
*/

// Prevent the direct loading of the file
if ( ! defined( 'ABSPATH' ) ) {
	die( esc_html__('You cannot access this file directly', 'apola') );
}

if(!class_exists('ApolaGalleryRepository') || !class_exists('ApolaPostRepository')) return;

global $Apola, $post, $ApolaPostLiker;

// Getting the content options
$apola_content_source = $Apola->getThemeOption('apola-page-type-portfolio-gallery-content-source', 'apola-portfolio');
$apola_content_item_show_likes = $Apola->getThemeOption('apola-page-type-portfolio-gallery-item-show-likes', 1);
$apola_content_item_show_categories = $Apola->getThemeOption('apola-page-type-portfolio-gallery-item-show-categories', 1);
$apola_is_gallery = $apola_content_source == 'apola-gallery';

// Getting the query arguments
$apola_query_paged = get_query_var('paged') ? get_query_var('paged') : 1;
$apola_query_limit = $Apola->getThemeOption('apola-page-type-portfolio-gallery-items-per-page', 16);
$apola_query_orderby = $Apola->getThemeOption('apola-page-type-portfolio-gallery-order-by', 'date');
$apola_query_order = $Apola->getThemeOption('apola-page-type-portfolio-gallery-sort-order', 'desc');
$apola_query_offset = $Apola->getThemeOption('apola-page-type-portfolio-gallery-portfolio-offset', 0);
$apola_query_exclude = $Apola->getThemeOption(sprintf('apola-page-type-portfolio-gallery-%s-out', ($apola_is_gallery ? 'galleries' : 'portfolio')), array());
$apola_query_include = $Apola->getThemeOption(sprintf('apola-page-type-portfolio-gallery-%s-in', ($apola_is_gallery ? 'galleries' : 'portfolio')), array());
$apola_query_cats = $Apola->getThemeOption(sprintf('apola-page-type-portfolio-gallery-%s-categories', ($apola_is_gallery ? 'galleries' : 'portfolio')), array());

$ApolaPostsRepository = $apola_is_gallery ? new ApolaGalleryRepository() : new ApolaPostRepository('apola-portfolio');
$ApolaPostLiker = new ApolaPostLiker($ApolaPostsRepository);

$apola_posts = $ApolaPostsRepository->fromCategories($apola_query_cats, ($apola_is_gallery ? 'apola-gallery-categories' : 'apola-portfolio-categories'))
									->in($apola_query_include)
									->out($apola_query_exclude)
									->orderBy($apola_query_orderby)
									->order($apola_query_order)
									->offset(($apola_query_paged - 1) * intval($apola_query_limit))
									->limit($apola_query_limit)
									->get();

set_query_var('apola-content-item-show-categories', $apola_content_item_show_categories);

get_header(); ?>

<div class="apo-section apo-full-width apo-without-vertical-padding">
	<?php if(is_array($apola_posts) && count($apola_posts)) :

		$apola_first_post = $apola_posts[0];
		if($apola_first_post instanceof WP_Post) {
			$apola_first_post_id = $apola_first_post->ID;
		}
		elseif(is_array($apola_first_post) && isset($apola_first_post['attach_id'])) {
			$apola_first_post_id = $apola_first_post['attach_id'];
		}

		$apola_item_ajax_data = array(
			'item_id' => $apola_first_post_id,
			'post_type' => $apola_is_gallery ? 'apola-galleries' : 'apola-portfolio',
			'likes' => $ApolaPostLiker->getLikesCount($apola_first_post_id),
			'parent_gallery_id' => (is_array($apola_first_post) && isset($apola_first_post['parent_gallery_id'])) ? $apola_first_post['parent_gallery_id'] : null
		);
	?>

	    <!-- - - - - - - - - - - - - - Photo stream actions - - - - - - - - - - - - - -->
	    <ul class="apo-photo-stream-actions">
			<?php if($apola_content_item_show_likes == 1) : ?>
		        <li>
		            <button class="apo-hover-btn apo-photo-likes-btn"
					 		type="button"
							data-item-likes-data="<?php echo esc_attr(wp_json_encode($apola_item_ajax_data)); ?>">
						<span class="apo-hover-btn-tooltip apo-item-likes"><?php echo esc_html($apola_item_ajax_data['likes']); ?></span>
						<i class="icon icon-heart"></i>
					</button>
		        </li>
			<?php endif; ?>

	        <li>
	            <button type="button"
						class="apo-hover-btn apo-photo-info-invoker"
						data-arctic-modal="true"
						data-arctic-modal-type="ajax"
						data-arctic-modal-ajax-action="show_item_info_modal"
						data-arctic-modal-ajax-data="<?php echo esc_attr(wp_json_encode($apola_item_ajax_data)); ?>">
					<i class="icon icon-menu-circle"></i>
				</button>
	        </li>
	    </ul>
	    <!-- - - - - - - - - - - - - - End of Photo stream actions - - - - - - - - - - - - - -->

        <!-- - - - - - - - - - - - - - Photo stream - - - - - - - - - - - - - -->
        <div id="apo-full-page" class="apo-full-page-container apo-photo-stream">
            <?php
				foreach($apola_posts as $index => $post) {
					set_query_var('apola-need-scroll-down-icon', $index == 0);

					if(!$apola_is_gallery) {
						setup_postdata($post);
						get_template_part('template-parts/apola-portfolio/apola-portfolio', 'fullpage-post');
					}
					else {
						set_query_var('apola-current-gallery-image', serialize($post));
						get_template_part('template-parts/apola-galleries/apola-galleries', 'fullpage-post');
					}
				}
				wp_reset_postdata();
			?>
        </div>
        <!-- - - - - - - - - - - - - - End of Photo stream - - - - - - - - - - - - - -->
    <?php else : ?>
		<div class="apo-section apo-section-no-content">
			<div class="container">
				<?php get_template_part('template-parts/content', 'none'); ?>
			</div>
		</div>
	<?php endif; ?>
</div>

<?php get_footer(); ?>
