<?php
/**
* The template file for displaying a portfolio/gallery page with "grid" style.
*
* @package WordPress
* @subpackage Apola
* @since Apola 1.0
*/

// Prevent the direct loading of the file
if ( ! defined( 'ABSPATH' ) ) {
	die( esc_html__('You cannot access this file directly', 'apola') );
}
if(!class_exists('ApolaGalleryRepository') || !class_exists('ApolaPostRepository')) return;

global $Apola, $post;
$ApolaHelper = $Apola->helper();

// Getting the content options
$apola_content_source = $Apola->getThemeOption('apola-page-type-portfolio-gallery-content-source', 'apola-portfolio');
$apola_content_columns = $Apola->getThemeOption('apola-page-type-portfolio-gallery-columns', 'apo-cols-4');
$apola_content_item_style = $Apola->getThemeOption('apola-page-type-portfolio-gallery-item-style', 'apo-style-3');
$apola_content_items_slide_effect = $Apola->getThemeOption('apola-page-type-portfolio-gallery-isotope-slide-effect', '1');
$apola_content_item_show_categories = $Apola->getThemeOption('apola-page-type-portfolio-gallery-item-show-categories', 1);
$apola_content_item_show_likes = $Apola->getThemeOption('apola-page-type-portfolio-gallery-item-show-likes', 1);
$apola_is_gallery = $apola_content_source == 'apola-gallery';

// Getting the query arguments
$apola_query_paged = get_query_var('paged') ? get_query_var('paged') : 1;
$apola_query_limit = $Apola->getThemeOption('apola-page-type-portfolio-gallery-items-per-page', 16);
$apola_query_orderby = $Apola->getThemeOption('apola-page-type-portfolio-gallery-order-by', 'date');
$apola_query_order = $Apola->getThemeOption('apola-page-type-portfolio-gallery-sort-order', 'desc');
$apola_query_offset = $Apola->getThemeOption('apola-page-type-portfolio-gallery-portfolio-offset', 0);
$apola_query_exclude = $Apola->getThemeOption(sprintf('apola-page-type-portfolio-gallery-%s-out', ($apola_is_gallery ? 'galleries' : 'portfolio')), array());
$apola_query_include = $Apola->getThemeOption(sprintf('apola-page-type-portfolio-gallery-%s-in', ($apola_is_gallery ? 'galleries' : 'portfolio')), array());
$apola_query_cats = $Apola->getThemeOption(sprintf('apola-page-type-portfolio-gallery-%s-categories', ($apola_is_gallery ? 'galleries' : 'portfolio')), array());

// Getting the page layout options
$apola_single_page_layout = $Apola->getThemeOption('apola-page-layout', 'apo-no-sidebar', array(
	'overriden_by' => 'apola-page-type-portfolio-gallery-layout',
	'depend_on' => array( 'key' => 'apola-page-settings-inherit-individual', 'value' => 0 )
));
$apola_page_vertical_padding = $Apola->getThemeOption('apola-page-vertical-padding', array('padding-top' => 85, 'padding-bottom' => 85));
$apola_page_top_padding_individual = $Apola->getThemeOption('apola-page-type-portfolio-gallery-top-padding');
$apola_page_bottom_padding_individual = $Apola->getThemeOption('apola-page-type-portfolio-gallery-bottom-padding');
$apola_page_title = $Apola->getThemeOption('apola-page-title', 'apo-style-1', array(
	'overriden_by' => 'apola-page-type-portfolio-gallery-page-title',
	'depend_on' => array( 'key' => 'apola-page-type-individual', 'value' => 'apola-portfolio-gallery' )
));
$apola_page_title_position = $Apola->getThemeOption('apola-page-title-position', 'apo-align-left', array(
	'overriden_by' => 'apola-page-type-portfolio-gallery-page-title-position',
	'depend_on' => array( 'key' => 'apola-page-type-individual', 'value' => 'apola-portfolio-gallery' )
));
$apola_page_breadcrumbs = $Apola->getThemeOption('apola-page-breadcrumbs', '0', array(
	'overriden_by' => 'apola-page-type-portfolio-gallery-breadcrumbs',
	'depend_on' => array( 'key' => 'apola-page-type-individual', 'value' => 'apola-portfolio-gallery' )
));
$apola_page_filter_state = $Apola->getThemeOption('apola-page-type-portfolio-gallery-filter', '1');
$apola_page_filter_all_tab_text = $Apola->getThemeOption('apola-page-type-portfolio-gallery-filter-all-tab-text', esc_html__('All', 'apola'));
$apola_page_pagination = $Apola->getThemeOption('apola-page-type-portfolio-gallery-pagination', 0);
$apola_page_back_to_top = $Apola->getThemeOption('apola-page-type-portfolio-gallery-back-to-top', 0);
$apola_page_back_to_top_btn_text = $Apola->getThemeOption('apola-page-type-portfolio-gallery-back-to-top-text', esc_html__('Back to top', 'apola'));
$apola_page_back_to_top_btn_message = $Apola->getThemeOption('apola-page-type-portfolio-gallery-back-to-top-message', esc_html__("You've reached the end of the list", 'apola'));

if(strlen($apola_page_top_padding_individual)) {
	$apola_page_vertical_padding['padding-top'] = intval($apola_page_top_padding_individual);
}
if(strlen($apola_page_bottom_padding_individual)) {
	$apola_page_vertical_padding['padding-bottom'] = intval($apola_page_bottom_padding_individual);
}

// Definition of the necessary variables
$apola_section_classes = array();
$apola_container_classes = array( $apola_content_columns, $apola_content_item_style );
$apola_has_sidebar = in_array($apola_single_page_layout, array('apo-left-sidebar', 'apo-right-sidebar'));
$apola_layout_classes = $ApolaHelper->getMainLayoutClasses($apola_single_page_layout);
$ApolaPostsRepository = $apola_is_gallery ? new ApolaGalleryRepository() : new ApolaPostRepository('apola-portfolio');

if($apola_content_items_slide_effect == 1 && in_array($apola_content_item_style, array('apo-style-2', 'apo-style-3', 'apo-style-4'))) {
	array_push($apola_container_classes, 'apo-isotope-has-slide-effect');
}

if($apola_single_page_layout == 'apo-full-width') {
	array_push($apola_section_classes, 'apo-full-width');
}
else {
	array_push($apola_section_classes, ($apola_has_sidebar ? 'apo-has-sidebar' : 'apo-has-not-sidebar'));
}

$apola_posts = $ApolaPostsRepository->fromCategories($apola_query_cats, ($apola_is_gallery ? 'apola-gallery-categories' : 'apola-portfolio-categories'))
									->in($apola_query_include)
									->out($apola_query_exclude)
									->orderBy($apola_query_orderby)
									->order($apola_query_order)
									->offset(($apola_query_paged - 1) * intval($apola_query_limit))
									->limit($apola_query_limit)
									->get();

set_query_var('apola-content-item-show-categories', $apola_content_item_show_categories);
set_query_var('apola-content-item-show-likes', $apola_content_item_show_likes);
set_query_var('apola-content-item-need-excerpt', ($apola_content_item_style == 'apo-style-6'));

get_header();
?>

<?php if($apola_page_title != 'apo-hidden' || $apola_page_filter_state != 0) : ?>
	<!-- - - - - - - - - - - - - - Page Header - - - - - - - - - - - - - - - - -->
	<div class="apo-page-header <?php echo sanitize_html_class($apola_page_title); ?>">
        <?php if($apola_page_title != 'apo-hidden') : ?>
    	    <div class="apo-page-header-column <?php echo sanitize_html_class($apola_page_title_position); ?>">
    	        <h1 class="apo-page-title"><?php the_title(); ?></h1>
    			<?php if($apola_page_breadcrumbs == 1 ) : ?>
    				<!-- - - - - - - - - - - - - - Breadcrumbs - - - - - - - - - - - - - - - - -->
    				<?php apola_breadcrumbs(); ?>
    				<!-- - - - - - - - - - - - - - End of Breadcrumbs - - - - - - - - - - - - - - - - -->
    			<?php endif; ?>
    	    </div>
        <?php endif; ?>

        <?php if($apola_page_filter_state == '1') : ?>
            <div class="apo-page-header-column">
                <!-- - - - - - - - - - - - - - Isotope Filter - - - - - - - - - - - - - - - - -->
                <?php apola_display_filter(
						$apola_posts,
						'apola-portfolio-filter',
						esc_html($apola_page_filter_all_tab_text),
						($apola_content_source == 'apola-portfolio' ? 'apola-portfolio-categories' : 'apola-gallery-categories'),
						'parent_gallery_id'
				); ?>
                <!-- - - - - - - - - - - - - - End of Isotope Filter - - - - - - - - - - - - - - - - -->
            </div>
        <?php endif; ?>
	</div>
	<!-- - - - - - - - - - - - - - End of Page Header - - - - - - - - - - - - - - - - -->
<?php endif; ?>

<div class="apo-section <?php echo esc_attr($ApolaHelper->getSanitizedHtmlClasses($apola_section_classes)); ?>" style="padding-top: <?php echo esc_attr($apola_page_vertical_padding['padding-top']); ?>px; padding-bottom: <?php echo esc_attr($apola_page_vertical_padding['padding-bottom']); ?>px;">
	<div class="row">
		<!-- - - - - - - - - - - - - - Main Content Column - - - - - - - - - - - - - - - - -->
		<main class="<?php echo esc_attr($ApolaHelper->getSanitizedHtmlClasses($apola_layout_classes['main_column'])); ?>">
			<?php if(is_array($apola_posts) && count($apola_posts)) : ?>
				<div class="apo-section">
	                <!-- - - - - - - - - - - - - - Isotope Container - - - - - - - - - - - - - -->
	                <div class="apo-isotope apo-portfolio-container <?php echo esc_attr($ApolaHelper->getSanitizedHtmlClasses($apola_container_classes)); ?>"
						 data-isotope-filter="#apola-portfolio-filter"
						 data-isotope-layout="grid">
	                    <div class="grid-sizer"></div>

	                    <?php foreach($apola_posts as $post) :
							if(!$apola_is_gallery) setup_postdata($post);
							else set_query_var('apola-current-gallery-image', serialize($post));
						?>
							<div class="<?php echo esc_attr($ApolaHelper->getSanitizedHtmlClasses(get_post_class('apo-item', ($apola_is_gallery ? $post['parent_gallery_id'] : get_the_ID())))); ?>">
								<?php get_template_part(sprintf('template-parts/apola-%s/apola-%1$s', $apola_is_gallery ? 'galleries' : 'portfolio'), 'post'); ?>
							</div>
	                    <?php endforeach; wp_reset_postdata(); ?>
	                </div>
	                <!-- - - - - - - - - - - - - - End of Isotope Container - - - - - - - - - - - - - -->
				</div>


				<?php if($apola_page_pagination == 1) : ?>
					<!-- - - - - - - - - - - - - - Page Controls - - - - - - - - - - - - - - - - -->
					<div class="apo-page-controls apo-medium"><?php apola_pagination(array(
                        'total'   => ceil( count($ApolaPostsRepository) / $apola_query_limit ),
                        'current' => $apola_query_paged
                    )); ?></div>
					<!-- - - - - - - - - - - - - - End of Page Controls - - - - - - - - - - - - - - - - -->
				<?php elseif($apola_page_back_to_top == 1) : ?>
					<!-- - - - - - - - - - - - - - Page Controls - - - - - - - - - - - - - - - - -->
					<div class="apo-page-controls apo-medium">
						<?php if(!empty($apola_page_back_to_top_btn_text)) : ?>
							<div class="apo-back-to-top-message"><?php echo esc_html($apola_page_back_to_top_btn_message); ?></div>
						<?php endif; ?>

						<button type="button" class="apo-back-to-top-button"><i class="icon-chevron-up"></i><?php echo esc_html($apola_page_back_to_top_btn_text); ?></button>
					</div>
					<!-- - - - - - - - - - - - - - End of Page Controls - - - - - - - - - - - - - - - - -->
				<?php endif; ?>
			<?php else : ?>
				<?php get_template_part('template-parts/content', 'none'); ?>
			<?php endif; ?>
			<?php if(comments_open()) : ?>
				<hr/>
				<?php comments_template(); ?>
			<?php endif; ?>
		</main>
		<!-- - - - - - - - - - - - - - End of Main Content Column - - - - - - - - - - - - - - - - -->

		<?php if($apola_has_sidebar) : ?>
			<!-- - - - - - - - - - - - - - Sidebar - - - - - - - - - - - - - - - - -->
			<aside class="apo-sidebar <?php echo esc_attr($ApolaHelper->getSanitizedHtmlClasses($apola_layout_classes['side_column'])); ?>" id="apo-sidebar">
				<?php get_sidebar(); ?>
			</aside>
			<!-- - - - - - - - - - - - - - End of Sidebar - - - - - - - - - - - - - - - - -->
		<?php endif; ?>
	</div>
</div>

<?php get_footer(); ?>
