<?php
/**
* The template file for displaying a portfolio/gallery page with "slideshow" style.
*
* @package WordPress
* @subpackage Apola
* @since Apola 1.0
*/

// Prevent the direct loading of the file
if ( ! defined( 'ABSPATH' ) ) {
	die( esc_html__('You cannot access this file directly', 'apola') );
}

if(!class_exists('ApolaGalleryRepository') || !class_exists('ApolaPostRepository')) return;

global $Apola, $post;

$apola_header_color_scheme = $Apola->getThemeOption('apola-header-side-color-scheme', 'apo-header-light', array(
	'overriden_by' => 'apola-page-header-side-color-scheme-individual',
	'depend_on' => array( 'key' => 'apola-page-header-state-individual', 'value' => '0' )
));
$apola_header_type = $Apola->getThemeOption('apola-header-type', 'apola-header-side', array(
	'overriden_by' => 'apola-page-header-type-individual',
	'depend_on' => array( 'key' => 'apola-page-header-state-individual', 'value' => '0' )
));

$apola_header_horizontal_color_scheme_slideshow = $Apola->getThemeOption('apola-page-header-top-color-scheme-slideshow-individual', 'apo-header-dark');
$apola_page_background_audio = $Apola->getThemeOption('apola-page-type-portfolio-gallery-slideshow-audio', null);

// Getting the slider options
$apola_slide_duration = $Apola->getThemeOption('apola-page-type-portfolio-gallery-slideshow-duration', 500);
$apola_slide_transition = $Apola->getThemeOption('apola-page-type-portfolio-gallery-slideshow-transition', 'fade');

// Getting the content options
$apola_content_source = $Apola->getThemeOption('apola-page-type-portfolio-gallery-content-source', 'apola-portfolio');
$apola_is_gallery = $apola_content_source == 'apola-gallery';
$ApolaPostsRepository = $apola_is_gallery ? new ApolaGalleryRepository() : new ApolaPostRepository('apola-portfolio');
$ApolaPostLiker = new ApolaPostLiker($ApolaPostsRepository);
$apola_header_likes_state = $Apola->getThemeOption('apola-page-header-portfolio-slideshow-show-likes', 1);

// Getting the query arguments
$apola_query_paged = get_query_var('paged') ? get_query_var('paged') : 1;
$apola_query_limit = $Apola->getThemeOption('apola-page-type-portfolio-gallery-items-per-page', 16);
$apola_query_orderby = $Apola->getThemeOption('apola-page-type-portfolio-gallery-order-by', 'date');
$apola_query_order = $Apola->getThemeOption('apola-page-type-portfolio-gallery-sort-order', 'desc');
$apola_query_offset = $Apola->getThemeOption('apola-page-type-portfolio-gallery-portfolio-offset', 0);
$apola_query_exclude = $Apola->getThemeOption(sprintf('apola-page-type-portfolio-gallery-%s-out', ($apola_is_gallery ? 'galleries' : 'portfolio')), array());
$apola_query_include = $Apola->getThemeOption(sprintf('apola-page-type-portfolio-gallery-%s-in', ($apola_is_gallery ? 'galleries' : 'portfolio')), array());
$apola_query_cats = $Apola->getThemeOption(sprintf('apola-page-type-portfolio-gallery-%s-categories', ($apola_is_gallery ? 'galleries' : 'portfolio')), array());

$apola_posts = $ApolaPostsRepository->fromCategories($apola_query_cats, ($apola_is_gallery ? 'apola-gallery-categories' : 'apola-portfolio-categories'))
									->in($apola_query_include)
									->out($apola_query_exclude)
									->orderBy($apola_query_orderby)
									->order($apola_query_order)
									->offset(($apola_query_paged - 1) * intval($apola_query_limit))
									->limit($apola_query_limit)
									->get();

$apola_fullscreen_controls_scheme = $apola_header_color_scheme == 'apo-header-light' ? 'apo-fullscreen-controls-light' : 'apo-fullscreen-controls-dark';

if($apola_header_type == 'apola-header-top') {
	$apola_fullscreen_controls_scheme = $apola_header_horizontal_color_scheme_slideshow == 'apo-header-light' ? 'apo-fullscreen-controls-light' : 'apo-fullscreen-controls-dark';
}

get_header(); ?>

<?php if($apola_page_background_audio && preg_match('/[.mp3]$/', $apola_page_background_audio)) : ?>
	<audio src="<?php echo esc_url($apola_page_background_audio); ?>" autoplay="true" class="apo-slider-audio"></audio>
<?php endif; ?>

<?php if(is_array($apola_posts) && count($apola_posts)) : ?>
	<!-- - - - - - - - - - - - - - Revolution Slider - - - - - - - - - - - - - -->
	<div class="rev_slider_wrapper fullscreen-container">
		<div id="rev-slider-1" class="rev_slider fullscreenbanner apo-revslider-theme">
			<ul>
				<?php foreach($apola_posts as $post) :
					$apola_item_ajax_data = array(
						'post_type' => $apola_is_gallery ? 'apola-galleries' : 'apola-portfolio'
					);

					if($post instanceof WP_Post) {
						setup_postdata($post);
						$apola_item_ajax_data['item_id'] = $post->ID;
					}
					elseif(is_array($post) && isset($post['attach_id'])) {
						$apola_post_id = $post['attach_id'];
						$apola_item_ajax_data['item_id'] = $post['attach_id'];

						if(isset($post['parent_gallery_id'])) {
							$apola_item_ajax_data['parent_gallery_id'] = $post['parent_gallery_id'];
						}
					}

					if(isset($apola_item_ajax_data['item_id']) && is_numeric($apola_item_ajax_data['item_id'])) {
						$apola_item_ajax_data['likes'] = $ApolaPostLiker->getLikesCount($apola_item_ajax_data['item_id']);
					}
				?>
					<li data-transition="<?php echo esc_attr($apola_slide_transition); ?>"
						data-speed="<?php echo esc_attr(intval($apola_slide_duration)); ?>"
						data-post-data="<?php echo esc_attr(wp_json_encode($apola_item_ajax_data)); ?>">
						<?php if(!$apola_is_gallery) : ?>
							<?php the_post_thumbnail('apola-full-screen-thumb'); ?>
						<?php elseif(isset($apola_item_ajax_data['item_id'])) : ?>
							<?php echo wp_get_attachment_image($apola_item_ajax_data['item_id'], 'apola-full-screen-thumb'); ?>
						<?php endif; ?>
					</li>
				<?php endforeach; wp_reset_postdata(); ?>
			</ul>

			<!-- - - - - - - - - - - - - - Slider Controls - - - - - - - - - - - - - -->
			<div class="apo-revslider-controls apo-right">
				<div class="apo-revslider-controls-item">
					<div class="apo-revslider-theme-nav-prev">
						<div class="apo-revslider-control-title"><?php esc_html_e('Prev', 'apola'); ?></div>
						<i class="apola-icon-prev"></i>
					</div>
				</div>

				<div class="apo-revslider-controls-item apo-playing">
					<div class="apo-revslider-control-pause">
						<div class="apo-revslider-control-title"><?php esc_html_e('Pause', 'apola'); ?></div>
						<i class="apola-icon-pause"></i>
					</div>

					<div class="apo-revslider-control-play">
						<div class="apo-revslider-control-title"><?php esc_html_e('Play', 'apola'); ?></div>
						<i class="apola-icon-play"></i>
					</div>
				</div>

				<div class="apo-revslider-controls-item">
					<div class="apo-revslider-theme-nav-next">
						<div class="apo-revslider-control-title"><?php esc_html_e('Next', 'apola'); ?></div>
						<i class="apola-icon-next"></i>
					</div>
				</div>
			</div>
			<!-- - - - - - - - - - - - - - End of Slider Controls - - - - - - - - - - - - - -->
		</div>

		<div class="apo-slider-fullscreen-controls <?php echo sanitize_html_class($apola_fullscreen_controls_scheme); ?>">
			<div class="container">
				<div class="apo-hr-controls">
					<div class="apo-hr-controls-component-first">
						<div class="apo-hr-controls-items">
							<div class="apo-hr-controls-item">
								<?php if(is_array($apola_posts) && count($apola_posts)) :
									$apola_first_post = $apola_posts[0];
									$apola_first_item_ajax_data = array(
										'post_type' => $apola_is_gallery ? 'apola-galleries' : 'apola-portfolio'
									);

									if($apola_first_post instanceof WP_Post) {
										$apola_first_item_ajax_data['item_id'] = $apola_first_post->ID;
									}
									elseif(is_array($apola_first_post) && isset($apola_first_post['attach_id'])) {
										$apola_first_item_ajax_data['item_id'] = $apola_first_post['attach_id'];

										if(isset($apola_first_post['parent_gallery_id'])) {
											$apola_first_item_ajax_data['parent_gallery_id'] = $apola_first_post['parent_gallery_id'];
										}
									}

									if(isset($apola_first_item_ajax_data['item_id']) && is_numeric($apola_first_item_ajax_data['item_id'])) {
										$apola_first_item_ajax_data['likes'] = $ApolaPostLiker->getLikesCount($apola_first_item_ajax_data['item_id']);
									}
			                	?>
									<?php if($apola_header_likes_state == 1) : ?>
				                        <!-- - - - - - - - - - - - - - Like Button - - - - - - - - - - - - - -->
				                        <button class="apo-hover-btn apo-item-likes-btn"
				                                type="button"
				                                data-item-likes-data="<?php echo esc_attr(wp_json_encode($apola_first_item_ajax_data)); ?>">
				                            <span class="apo-hover-btn-tooltip apo-item-likes"><?php echo esc_html($apola_first_item_ajax_data['likes']); ?></span>
				                            <i class="icon icon-heart"></i>
				                        </button>
				                        <!-- - - - - - - - - - - - - - End of Like Button - - - - - - - - - - - - - -->
									<?php endif; ?>
								<?php endif; ?>
							</div>
						</div>
					</div>

					<div class="apo-hr-controls-component-middle">
						<div class="apo-hr-controls-items">
							<div class="apo-hr-controls-item">
								<button type="button" class="apo-fullscreen-control-close">
									<i class="icon icon-cross"></i><?php esc_html_e('Close', 'apola'); ?>
								</button>
							</div>
						</div>
					</div>

					<div class="apo-hr-controls-component-last">
						<div class="apo-hr-controls-items">
							<div class="apo-hr-controls-item">
								<!-- - - - - - - - - - - - - - Slider Controls - - - - - - - - - - - - - -->
								<div class="apo-revslider-controls apo-right">
									<div class="apo-revslider-controls-item">
										<div class="apo-revslider-theme-nav-prev">
											<div class="apo-revslider-control-title"><?php esc_html_e('Prev', 'apola'); ?></div>
											<i class="apola-icon-prev"></i>
										</div>
									</div>

									<div class="apo-revslider-controls-item apo-playing">
										<div class="apo-revslider-control-pause">
											<div class="apo-revslider-control-title"><?php esc_html_e('Pause', 'apola'); ?></div>
											<i class="apola-icon-pause"></i>
										</div>

										<div class="apo-revslider-control-play">
											<div class="apo-revslider-control-title"><?php esc_html_e('Play', 'apola'); ?></div>
											<i class="apola-icon-play"></i>
										</div>
									</div>

									<div class="apo-revslider-controls-item">
										<div class="apo-revslider-theme-nav-next">
											<div class="apo-revslider-control-title"><?php esc_html_e('Next', 'apola'); ?></div>
											<i class="apola-icon-next"></i>
										</div>
									</div>
								</div>
								<!-- - - - - - - - - - - - - - End of Slider Controls - - - - - - - - - - - - - -->
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
	</div>
<?php else : ?>
	<!-- - - - - - - - - - - - - - Content Section - - - - - - - - - - - - - -->
	<div class="apo-section apo-section-no-content">
		<div class="container">
			<?php get_template_part('template-parts/content', 'none'); ?>
		</div>
	</div>
	<!-- - - - - - - - - - - - - - End of Content Section - - - - - - - - - - - - - -->
<?php endif; ?>

<?php get_footer(); ?>
