<?php
/**
* The template file for displaying a portfolio/gallery page with "slideshow" style.
*
* @package WordPress
* @subpackage Apola
* @since Apola 1.0
*/

// Prevent the direct loading of the file
if ( ! defined( 'ABSPATH' ) ) {
	die( esc_html__('You cannot access this file directly', 'apola') );
}

if(!class_exists('ApolaGalleryRepository') || !class_exists('ApolaPostRepository')) return;

global $Apola, $post;

// Getting the content options
$apola_content_source = $Apola->getThemeOption('apola-page-type-portfolio-gallery-content-source', 'apola-portfolio');
$apola_content_item_show_categories = $Apola->getThemeOption('apola-page-type-portfolio-gallery-item-show-categories', 1);
$apola_content_item_show_likes = $Apola->getThemeOption('apola-page-type-portfolio-gallery-item-show-likes', 1);
$apola_is_gallery = $apola_content_source == 'apola-gallery';
$ApolaPostsRepository = $apola_is_gallery ? new ApolaGalleryRepository() : new ApolaPostRepository('apola-portfolio');
$ApolaPostLiker = new ApolaPostLiker($ApolaPostsRepository);

// Getting the query arguments
$apola_query_paged = get_query_var('paged') ? get_query_var('paged') : 1;
$apola_query_limit = $Apola->getThemeOption('apola-page-type-portfolio-gallery-items-per-page', 16);
$apola_query_orderby = $Apola->getThemeOption('apola-page-type-portfolio-gallery-order-by', 'date');
$apola_query_order = $Apola->getThemeOption('apola-page-type-portfolio-gallery-sort-order', 'desc');
$apola_query_offset = $Apola->getThemeOption('apola-page-type-portfolio-gallery-portfolio-offset', 0);
$apola_query_exclude = $Apola->getThemeOption(sprintf('apola-page-type-portfolio-gallery-%s-out', ($apola_is_gallery ? 'galleries' : 'portfolio')), array());
$apola_query_include = $Apola->getThemeOption(sprintf('apola-page-type-portfolio-gallery-%s-in', ($apola_is_gallery ? 'galleries' : 'portfolio')), array());
$apola_query_cats = $Apola->getThemeOption(sprintf('apola-page-type-portfolio-gallery-%s-categories', ($apola_is_gallery ? 'galleries' : 'portfolio')), array());

$apola_posts = $ApolaPostsRepository->fromCategories($apola_query_cats, ($apola_is_gallery ? 'apola-gallery-categories' : 'apola-portfolio-categories'))
									->in($apola_query_include)
									->out($apola_query_exclude)
									->orderBy($apola_query_orderby)
									->order($apola_query_order)
									->offset(($apola_query_paged - 1) * intval($apola_query_limit))
									->limit($apola_query_limit)
									->get();

set_query_var('apola-content-item-show-categories', $apola_content_item_show_categories);
set_query_var('apola-content-item-show-likes', $apola_content_item_show_likes);

get_header(); ?>

<!-- - - - - - - - - - - - - - Content Section - - - - - - - - - - - - - -->
<main class="apo-section apo-without-vertical-padding">
    <?php if(is_array($apola_posts) && count($apola_posts)) : ?>
	    <!-- - - - - - - - - - - - - - Striped Carousel - - - - - - - - - - - - - -->
	    <div class="apo-striped-photos apo-full-height owl-carousel">
	        <?php
				foreach($apola_posts as $post) {
					if(!$apola_is_gallery) {
						setup_postdata($post);
						get_template_part('template-parts/apola-portfolio/apola-portfolio', 'striped-carousel-post');
					}
					else {
						set_query_var('apola-current-gallery-image', serialize($post));
						get_template_part('template-parts/apola-galleries/apola-galleries', 'striped-carousel-post');
					}
				}

				wp_reset_postdata();
			?>
	    </div>
    <?php else : ?>
		<div class="apo-section apo-section-no-content">
			<div class="container">
        		<?php get_template_part('template-parts/content', 'none'); ?>
			</div>
		</div>
    <?php endif; ?>
</main>
<!-- - - - - - - - - - - - - - Content Section - - - - - - - - - - - - - -->

<?php get_footer(); ?>
