<?php
/**
* The template file that responsible to display archive page of blog posts.
*
* @package WordPress
* @subpackage Apola
* @since Apola 1.0
*/

// Prevent the direct loading of the file
if ( ! defined( 'ABSPATH' ) ) {
	die( esc_html__('You cannot access this file directly', 'apola') );
}

global $Apola;
$ApolaHelper = $Apola->helper();

$apola_blog_display_style = $Apola->getThemeOption('blog-default-style', 'apo-style-3');
$apola_blog_isotope_layout = $Apola->getThemeOption('blog-isotope-layout-type', 'grid');
$apola_blog_columns = $Apola->getThemeOption('blog-default-columns', 'apo-cols-1');
$apola_post_archive_layout = $Apola->getThemeOption('post-archive-layout', 'apo-no-sidebar');
$apola_page_vertical_padding = $Apola->getThemeOption('post-archive-vertical-padding', array('padding-top' => 85, 'padding-bottom' => 85));
$apola_page_items_slide_effect = $Apola->getThemeOption('post-archive-isotope-slide-effect', '1');

set_query_var('apola-blog-post-style', $apola_blog_display_style);

$apola_blog_container_classes = array($apola_blog_display_style, $apola_blog_columns);

if(in_array($apola_blog_display_style, array('apo-style-1', 'apo-style-2', 'apo-style-3')) && $apola_page_items_slide_effect == 1) {
	array_push($apola_blog_container_classes, 'apo-isotope-has-slide-effect');
}

$apola_has_sidebar = in_array($apola_post_archive_layout, array('apo-left-sidebar', 'apo-right-sidebar'));
$apola_layout_classes = $ApolaHelper->getMainLayoutClasses($apola_post_archive_layout);

$apola_section_classes = array();

array_push($apola_section_classes, $apola_has_sidebar ? 'apo-has-sidebar' : 'apo-has-not-sidebar');

if(!$apola_has_sidebar && $apola_blog_columns == 'apo-cols-1') {
	array_push($apola_section_classes, 'apo-section-thin');
}

if($apola_post_archive_layout == 'apo-full-width') {
	array_push($apola_section_classes, 'apo-full-width');
}

?>
<div class="apo-section <?php echo esc_attr($ApolaHelper->getSanitizedHtmlClasses($apola_section_classes)); ?>" style="padding-top: <?php echo esc_attr($apola_page_vertical_padding['padding-top']); ?>px; padding-bottom: <?php echo esc_attr($apola_page_vertical_padding['padding-bottom']); ?>px;">
	<div class="row">
		<!-- - - - - - - - - - - - - - Main Content Column - - - - - - - - - - - - - - - - -->
		<main class="<?php echo esc_attr($ApolaHelper->getSanitizedHtmlClasses($apola_layout_classes['main_column'])); ?>">
			<?php if( have_posts() ) : ?>
				<div class="apo-section">
			        <!-- - - - - - - - - - - - - - Isotope Container - - - - - - - - - - - - - - - - -->
			        <div class="apo-isotope apo-entries-container <?php echo esc_attr($ApolaHelper->getSanitizedHtmlClasses($apola_blog_container_classes)); ?>"
						data-items-per-page="<?php echo esc_attr( get_option('posts_per_page') ); ?>"
						data-isotope-layout="<?php echo esc_attr( $apola_blog_isotope_layout ); ?>">
			            <?php
			                while( have_posts() ) : the_post();
			                    get_template_part( 'template-parts/post/blog', 'post' );
			                endwhile;
			            ?>

						<div class="grid-sizer"></div>
			        </div>
			        <!-- - - - - - - - - - - - - - End of Isotope Container - - - - - - - - - - - - - - - - -->
			    </div>

				<!-- - - - - - - - - - - - - - Pagination - - - - - - - - - - - - - - - - -->
				<div class="apo-page-controls"><?php apola_pagination(array( 'end_size' => 1 )); ?></div>
				<!-- - - - - - - - - - - - - - End of Pagination - - - - - - - - - - - - - - - - -->
			<?php else :
			    get_template_part('template-parts/content', 'none');
			endif;?>
		</main>
		<!-- - - - - - - - - - - - - - End of Main Content Column - - - - - - - - - - - - - - - - -->

		<?php if($apola_has_sidebar) : ?>
			<!-- - - - - - - - - - - - - - Sidebar - - - - - - - - - - - - - - - - -->
			<aside class="apo-sidebar <?php echo esc_attr($ApolaHelper->getSanitizedHtmlClasses($apola_layout_classes['side_column'])); ?>" id="apo-sidebar">
				<?php get_sidebar(); ?>
			</aside>
			<!-- - - - - - - - - - - - - - End of Sidebar - - - - - - - - - - - - - - - - -->
		<?php endif; ?>
	</div>
</div>
