<?php
/**
 * The blog post template file
 *
 * @package WordPress
 * @subpackage Apola
 * @since Apola 1.0
 */

// Prevent the direct loading of the file
if ( ! defined( 'ABSPATH' ) ) {
	die( esc_html__('You cannot access this file directly', 'apola') );
}

global $Apola;
$apola_blog_post_style = get_query_var('apola-blog-post-style', 'apo-style-3');
$apola_blog_post_thumb_size = get_query_var('apola-item-thumb-size', 'apola-blog-thumb-horizontal');
$apola_need_entry_background = in_array($apola_blog_post_style, array('apo-style-1', 'apo-style-4', 'apo-style-5'));
?>

<div <?php post_class('apo-item') ?>>
    <!-- - - - - - - - - - - - - - Entry - - - - - - - - - - - - - - - - -->
    <article <?php post_class(!has_post_thumbnail() ? 'apo-entry apo-entry-without-thumb' : 'apo-entry'); ?>>
        <div class="apo-entry-inner">
			<?php if( $apola_blog_post_style == 'apo-style-1' ) : ?>
				<header class="apo-entry-header-dublicate">
					<?php if(is_sticky() || post_password_required()) : ?>
						<div class="apo-entry-labels">
							<div class="apo-entry-labels-inner">
								<?php if(is_sticky()) : ?>
									<em class="apo-entry-label apo-entry-label-sticky apo-entry-label-red"><?php esc_html_e('Featured', 'apola'); ?></em>
								<?php endif; ?>

								<?php if(post_password_required()) : ?>
									<em class="apo-entry-label apo-entry-label-red"><?php esc_html_e('Password Protected', 'apola'); ?></em>
								<?php endif; ?>
							</div>
						</div>
					<?php endif; ?>

					<?php echo apola_get_post_terms(get_the_ID(), 'category'); ?>

					<h2 class="apo-entry-title">
						<a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
					</h2>
				</header>
			<?php endif; ?>

			<?php if( has_post_thumbnail() ) : ?>
            <!-- - - - - - - - - - - - - - Entry Media - - - - - - - - - - - - - - - - -->
            	<div class="apo-entry-media" <?php if($apola_need_entry_background) : ?>data-bg-img-src="<?php echo esc_url(get_the_post_thumbnail_url(get_the_ID(), $apola_blog_post_thumb_size)); ?>" <?php endif; ?>>
                    <a href="<?php the_permalink(); ?>" <?php if($apola_need_entry_background) : ?>aria-hidden="true" class="apo-entry-media-hidden-image"<?php endif; ?>>
                        <?php the_post_thumbnail($apola_blog_post_thumb_size); ?>
                    </a>

					<?php if(in_array($apola_blog_post_style, array('apo-style-2', 'apo-style-3'))) : ?>
						<?php if(is_sticky() || post_password_required()) : ?>
							<div class="apo-entry-labels">
								<div class="apo-entry-labels-inner">
									<?php if(is_sticky()) : ?>
										<em class="apo-entry-label apo-entry-label-sticky apo-entry-label-red"><?php esc_html_e('Featured', 'apola'); ?></em>
									<?php endif; ?>

									<?php if(post_password_required()) : ?>
										<em class="apo-entry-label apo-entry-label-red"><?php esc_html_e('Password Protected', 'apola'); ?></em>
									<?php endif; ?>
								</div>
							</div>
						<?php endif; ?>
					<?php endif; ?>
	            </div>
            <!-- - - - - - - - - - - - - - End of Entry Media - - - - - - - - - - - - - - - - -->
			<?php endif; ?>

            <!-- - - - - - - - - - - - - - Entry Content - - - - - - - - - - - - - - - - -->
            <div class="apo-entry-content-wrap">
                <div class="apo-aligner-outer">
                    <div class="apo-aligner-inner">
                        <header class="apo-entry-header">
							<?php if(in_array($apola_blog_post_style, array('apo-style-1', 'apo-style-4', 'apo-style-5')) || (!has_post_thumbnail() && in_array($apola_blog_post_style, array('apo-style-2', 'apo-style-3')))) : ?>
								<?php if(is_sticky() || post_password_required()) : ?>
									<div class="apo-entry-labels">
										<div class="apo-entry-labels-inner">
											<?php if(is_sticky()) : ?>
												<em class="apo-entry-label apo-entry-label-sticky apo-entry-label-red"><?php esc_html_e('Featured', 'apola'); ?></em>
											<?php endif; ?>

											<?php if(post_password_required()) : ?>
												<em class="apo-entry-label apo-entry-label-red"><?php esc_html_e('Password Protected', 'apola'); ?></em>
											<?php endif; ?>
										</div>
									</div>
								<?php endif; ?>
							<?php endif; ?>

							<?php if($apola_blog_post_style != 'apo-style-5') : ?>
                            	<?php echo apola_get_post_terms( get_the_ID(), 'category' ); ?>
							<?php endif; ?>

                            <h2 class="apo-entry-title">
                                <a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
                            </h2>

							<?php if($apola_blog_post_style == 'apo-style-5') : ?>
								<div class="apo-entry-meta">
									<time datetime="<?php echo esc_attr(get_the_date('c')); ?>" class="apo-entry-publish-date"><?php echo get_the_date(get_option('date_format')); ?></time>
								</div>
							<?php endif; ?>
                        </header>

						<?php if($apola_blog_post_style == 'apo-style-1' || is_search()) : ?>
							<div class="apo-entry-content"><?php the_excerpt(); ?></div>
						<?php elseif( in_array($apola_blog_post_style, array('apo-style-2', 'apo-style-3')) ) : ?>
							<div class="apo-entry-content"><?php the_content(); ?></div>
							<?php wp_link_pages( array(
								'before' => '<div class="apo-page-links"><span class="apo-page-links-title">' . esc_html__( 'Pages:', 'apola' ) . '</span>',
								'after' => '</div>',
								'link_before' => '<span>',
								'link_after' => '</span>'
							) ); ?>
						<?php endif; ?>

                        <footer class="apo-entry-footer">
							<?php if(in_array($apola_blog_post_style, array('apo-style-1', 'apo-style-5'))) : ?>
								<a href="<?php the_permalink(); ?>" class="apo-entry-read-more-link apo-btn apo-btn-small"><?php esc_html_e('Read More', 'apola'); ?></a>
							<?php elseif($apola_blog_post_style == 'apo-style-2') : ?>
								<a href="<?php the_permalink(); ?>" class="apo-entry-read-more-link apo-btn apo-btn-mini"><?php esc_html_e('Read More', 'apola'); ?></a>
							<?php else : ?>
                            	<a href="<?php the_permalink(); ?>" class="apo-entry-publish-date"><time datetime="<?php echo esc_attr(get_the_date('c')); ?>"><?php echo esc_html(get_the_date(get_option('date_format'))); ?></time></a>
							<?php endif; ?>
                        </footer>
                    </div>
                </div>
            </div>
        </div>
    </article>
    <!-- - - - - - - - - - - - - - End of Entry - - - - - - - - - - - - - - - - -->
</div>
