<?php
/**
* The template for displaying a single post.
*
* @package WordPress
* @subpackage Apola
* @since Apola 1.0
*/

// Prevent the direct loading of the file
if ( ! defined( 'ABSPATH' ) ) {
	die( esc_html__('You cannot access this file directly', 'apola') );
}

global $Apola;
$ApolaHelper = $Apola->helper();

$apola_single_post_layout = $Apola->getThemeOption('post-single-layout', 'apo-right-sidebar', array(
	'overriden_by' => 'post-single-layout-individual',
	'depend_on' => array( 'key' => 'post-single-layout-state-individual', 'value' => '0' )
));

$apola_has_sidebar = in_array($apola_single_post_layout, array('apo-left-sidebar', 'apo-right-sidebar'));
$apola_layout_classes = $ApolaHelper->getMainLayoutClasses($apola_single_post_layout);
$apola_single_post_tags = $Apola->getThemeOption('post-single-show-tags', '1');
$apola_single_post_social_links = $Apola->getThemeOption('post-single-show-social-links', '0');
$apola_single_post_comments = $Apola->getThemeOption('post-single-show-comments', '1');

get_header(); ?>

<div class="apo-section <?php if($apola_has_sidebar) echo sanitize_html_class('apo-has-sidebar'); ?>">
	<div class="row">
		<!-- - - - - - - - - - - - - - Main Content Column - - - - - - - - - - - - - - - - -->
		<main class="<?php echo esc_attr($ApolaHelper->getSanitizedHtmlClasses($apola_layout_classes['main_column'])); ?>">
			<?php if(have_posts()) : ?>
		        <?php while( have_posts() ) : the_post(); ?>
					<div class="apo-section apo-section-thin apo-medium">
				        <!-- - - - - - - - - - - - - - Single Entry - - - - - - - - - - - - - - - - -->
				        <article <?php post_class('apo-entry apo-single') ?>>
				            <?php if( has_post_thumbnail() && !post_password_required() ) : ?>
				                <!-- - - - - - - - - - - - - - Entry Media - - - - - - - - - - - - - - - - -->
				                <div class="apo-entry-media">
				                    <?php the_post_thumbnail('full'); ?>
				                </div>
				                <!-- - - - - - - - - - - - - - End of Entry Media - - - - - - - - - - - - - - - - -->
				            <?php endif; ?>

				            <!-- - - - - - - - - - - - - - Entry Content - - - - - - - - - - - - - - - - -->
				            <div class="apo-entry-content-wrap">
				                <header class="apo-entry-header">
									<?php if(!empty(get_the_title())) : ?>
				                    	<h2 class="apo-entry-title"><?php the_title(); ?></h2>
									<?php endif; ?>

				                    <ul class="apo-entry-meta">
				                        <li>
				                            <?php esc_html_e('Author:', 'apola'); ?>
				                            <a href="<?php echo esc_url(get_author_posts_url(get_the_author_meta('ID'))); ?>"><?php the_author(); ?></a>
				                        </li>
				                        <li>
				                            <?php esc_html_e('Published in:', 'apola'); ?>
				                            <a href="<?php echo esc_url(get_day_link(get_the_time('Y'), get_the_time('m'), get_the_time('d'))); ?>">
				                                <time datetime="<?php echo esc_attr(get_the_date('c')); ?>"><?php the_date(get_option('date_format')); ?></time>
				                            </a>
				                        </li>
				                        <?php if(apola_has_post_terms(get_the_ID())) : ?>
				                            <li><?php esc_html_e('Categories:', 'apola'); ?> <?php echo apola_get_post_terms(get_the_ID()); ?></li>
				                        <?php endif; ?>
				                    </ul>
				                </header>

				                <div class="apo-entry-content">
				                    <?php
				                        the_content();
				                        wp_link_pages( array(
				                            'before' => '<div class="apo-page-links"><span class="apo-page-links-title">' . esc_html__( 'Pages:', 'apola' ) . '</span>',
				                            'after' => '</div>',
				                            'link_before' => '<span>',
				                            'link_after' => '</span>'
				                        ) );
				                    ?>
				                </div>

								<?php if($apola_single_post_tags == '1' || $apola_single_post_social_links == '1') : ?>
					                <footer class="apo-entry-footer">
					                    <div class="row apo-table-row-md">
											<?php if($apola_single_post_tags == '1') : ?>
					                        	<div class="<?php echo sanitize_html_class($apola_single_post_social_links == '1' ? 'col-md-6' : 'col-md-12'); ?>">
						                            <div class="apo-inline-block">
						                                <div class="apo-entry-tags"><?php the_tags(); ?></div>
						                            </div>
					                        	</div>
											<?php endif; ?>

											<?php if($apola_single_post_social_links == '1') : ?>
					                        	<div class="<?php echo sanitize_html_class($apola_single_post_tags == '1' ? 'col-md-6' : 'col-md-12'); ?>">
					                            	<div class="apo-inline-block">
														<?php
															/**
															 * Hook for the prepend some content to the end of the post content.
															 *
															 * @hooked
															 */
															do_action('apola_single_post_after_content', get_post());
														?>
						                            </div>
					                        	</div>
											<?php endif; ?>
					                    </div>
					                </footer>
								<?php endif; ?>
				            </div>
				        </article>
				        <!-- - - - - - - - - - - - - - End of Single Entry - - - - - - - - - - - - - - - - -->

						<?php if($apola_single_post_comments == '1') : ?>
							<hr/>
							<?php comments_template(); ?>
						<?php endif; ?>
					</div>

					<nav class="apo-entries-navigation">
						<?php previous_post_link('<div class="apo-entries-navigation-item apo-entries-navigation-item-prev"><div class="apo-entries-navigation-item-inner"><i class="icon-arrow-left"></i> %link</div></div>'); ?>
						<?php next_post_link('<div class="apo-entries-navigation-item apo-entries-navigation-item-next"><div class="apo-entries-navigation-item-inner"><i class="icon-arrow-right"></i> %link</div></div>'); ?>
					</nav>
		        <?php endwhile; ?>
			<?php else : ?>
				<?php get_template_part('template-parts/content', 'none'); ?>
			<?php endif; ?>
		</main>
		<!-- - - - - - - - - - - - - - End of Main Content Column - - - - - - - - - - - - - - - - -->

		<?php if($apola_has_sidebar) : ?>
			<!-- - - - - - - - - - - - - - Sidebar - - - - - - - - - - - - - - - - -->
			<aside class="apo-sidebar <?php echo esc_attr($ApolaHelper->getSanitizedHtmlClasses($apola_layout_classes['side_column'])); ?>" id="apo-sidebar">
				<?php get_sidebar(); ?>
			</aside>
			<!-- - - - - - - - - - - - - - End of Sidebar - - - - - - - - - - - - - - - - -->
		<?php endif; ?>
	</div>
</div>
<?php get_footer(); ?>
